(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    283279,       6158]
NotebookOptionsPosition[    279281,       6045]
NotebookOutlinePosition[    281153,       6096]
CellTagsIndexPosition[    280778,       6085]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Analytic Slip-link Expressions for Universal Dynamic Modulus Predictions of \
Linear Monodisperse Polymer Melts \
\>", "Title",
 CellChangeTimes->{{3.6231592510361624`*^9, 3.6231592988908997`*^9}, {
  3.6231665927730856`*^9, 3.6231666030326724`*^9}}],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "1"], TraditionalForm]]],
 "Katzarova M, ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "1"], TraditionalForm]]],
 "Yang L, ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "2"], TraditionalForm]]],
 "Andreev M, ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "1"], TraditionalForm]]],
 "C\[OAcute]rdoba A, ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", 
    RowBox[{
     RowBox[{"1", ",", "2", ",", "a"}], ")"}]], TraditionalForm]]],
 "Schieber JD. Analytic Slip-link Expressions for Universal Dynamic Modulus \
Predictions of Linear Monodisperse Polymer Melts, 2015. Rheologica Acta. \n\n",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "1"], TraditionalForm]]],
 "Department of Chemical and Biological Engineering, and Center for Molecular \
Study of Condensed Soft Matter, Illinois Institute of Technology, 3440 S. \
Dearborn St., Chicago, Illinois 60616, U.S.A.\n\n",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "2"], TraditionalForm]]],
 "Department of Physics, Illinois Institute of Technology, 3101 S. Dearborn \
St., Chicago, Illinois 60616, U.S.A.\n\n",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", 
    RowBox[{"a", ")"}]], TraditionalForm]]],
 "Corresponding author: schieber@iit.edu"
}], "Text",
 CellChangeTimes->{{3.623086272401023*^9, 3.6230862759452257`*^9}, {
  3.623086307105008*^9, 3.62308636692943*^9}, {3.6230864269288616`*^9, 
  3.623086539953326*^9}, {3.6296553259799824`*^9, 3.629655529590411*^9}, {
  3.629739344691455*^9, 3.629739349226715*^9}, {3.629739606707442*^9, 
  3.62973964461761*^9}, {3.6297397426532173`*^9, 3.6297397588531437`*^9}},
 Background->RGBColor[0.87, 0.94, 1]],

Cell[TextData[{
 "The expressions below were constructed from predictions for a wide range of \
entangled polymers (6-200 entanglements) using the discrete slip-link model \
(DSM). The DSM is able to predict simultaneously both nonlinear rheology and \
the linear viscoelasticity of monodisperse linear ",
 ButtonBox[Cell[TextData[StyleBox[ButtonBox["1"],
  FontVariations->{"CompatibilityType"->"Superscript"}]], "Citation",
  Editable->False,
  TaggingRules->{CitationData -> "bibl:andreev2014universality"}],
  BaseStyle->"Hyperlink",
  ButtonData->"bibl:andreev2014universality"],
 ", polydisperse linear ",
 ButtonBox[Cell[TextData[StyleBox[ButtonBox["2"],
  FontVariations->{"CompatibilityType"->"Superscript"}]], "Citation",
  Editable->False,
  TaggingRules->{CitationData -> "bibl:khaliullin2010application"}],
  BaseStyle->"Hyperlink",
  ButtonData->"bibl:khaliullin2010application"],
 ", branched ",
 ButtonBox[Cell[TextData[StyleBox[ButtonBox["3"],
  FontVariations->{"CompatibilityType"->"Superscript"}]], "Citation",
  Editable->False,
  TaggingRules->{CitationData -> "bibl:pilyugina2012dielectric"}],
  BaseStyle->"Hyperlink",
  ButtonData->"bibl:pilyugina2012dielectric"],
 ", and cross-linked systems ",
 ButtonBox[Cell[TextData[StyleBox[ButtonBox["4-5"],
  FontVariations->{"CompatibilityType"->"Superscript"}]], "Citation",
  Editable->False,
  TaggingRules->{
   CitationData -> {"bibl:jensen2012self", "bibl:katzarova2014rheological"}}],
  BaseStyle->"Hyperlink",
  ButtonData->"bibl:jensen2012self"],
 "."
}], "Text",
 CellChangeTimes->{{3.623172463021845*^9, 3.6231726959181657`*^9}, {
  3.6231727654471426`*^9, 3.6231728054784317`*^9}, {3.6231729275184126`*^9, 
  3.623172932565701*^9}, {3.6231730347245445`*^9, 3.6231730357416024`*^9}, {
  3.6231730857464623`*^9, 3.623173126390787*^9}, {3.6231731732324667`*^9, 
  3.6231732202461557`*^9}, {3.6231733102223015`*^9, 3.6231733489355164`*^9}, {
  3.6231733842445354`*^9, 3.6231733882567654`*^9}, {3.6231734926197343`*^9, 
  3.6231734972679996`*^9}, {3.6231738407886486`*^9, 3.6231738438028207`*^9}, {
  3.62317407631312*^9, 3.623174093327093*^9}, {3.6231742628307877`*^9, 
  3.62317426584296*^9}, {3.6231746058554077`*^9, 3.6231746413684387`*^9}, {
  3.6231748663833094`*^9, 3.623174869395481*^9}, {3.6233279022434006`*^9, 
  3.6233279218238235`*^9}, {3.6233279977373557`*^9, 3.6233280017574472`*^9}, {
  3.623328068215726*^9, 3.623328074625843*^9}},
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.453563650451541*^9, 3.453563672660181*^9}, {
   3.453567091977009*^9, 3.453567092232563*^9}, 3.4536612090057287`*^9, {
   3.45373079843165*^9, 3.4537307993380737`*^9}, {3.453743256156361*^9, 
   3.453743256650915*^9}, 3.45374729273378*^9, {3.4537474930152187`*^9, 
   3.453747516791271*^9}, 3.453753844787403*^9, {3.453754673463006*^9, 
   3.4537546746275253`*^9}, 3.4537567273732023`*^9, {3.453757114836465*^9, 
   3.453757115469458*^9}, 3.453757253434495*^9, 3.453757608021083*^9, {
   3.453757948526063*^9, 3.453757949527673*^9}, 3.453760224010479*^9, 
   3.453760472048521*^9, 3.453761063492012*^9, 3.4537618603783092`*^9, 
   3.453764963540779*^9, 3.453836724270018*^9, {3.4538372609811487`*^9, 
   3.4538372670058527`*^9}, {3.453906207561358*^9, 3.4539062369620657`*^9}, {
   3.453906692653276*^9, 3.453906730873005*^9}, {3.453907489302387*^9, 
   3.453907500714179*^9}, {3.509723325951255*^9, 3.509723371149508*^9}, 
   3.509825055872888*^9, 3.5140492195558724`*^9, {3.514049398906131*^9, 
   3.5140495133226748`*^9}, {3.5140526238595877`*^9, 3.514052624481623*^9}, {
   3.514117282948876*^9, 3.514117328551484*^9}, {3.5141175020964108`*^9, 
   3.5141175168002515`*^9}, {3.518971703482967*^9, 3.518971709066286*^9}, {
   3.519398871512974*^9, 3.5193988720090017`*^9}, {3.5193989076300397`*^9, 
   3.519398929297279*^9}, {3.519399096588847*^9, 3.5193991305707912`*^9}, {
   3.5194035204938803`*^9, 3.5194035209869084`*^9}, {3.5194035632083235`*^9, 
   3.519403563922364*^9}, {3.5195636196026726`*^9, 3.519563684980412*^9}, {
   3.5195637319851007`*^9, 3.5195637323651223`*^9}, {3.51956431364837*^9, 
   3.5195643330584803`*^9}, {3.5195644706163483`*^9, 
   3.5195645453856244`*^9}, {3.51956459792863*^9, 3.51956460807121*^9}, {
   3.521812015385617*^9, 3.5218120590551147`*^9}, 3.5370415521888103`*^9, {
   3.53712483784906*^9, 3.537124929039276*^9}, {3.5371249600750513`*^9, 
   3.5371252263952837`*^9}, {3.5371253284151187`*^9, 
   3.5371253606999655`*^9}, {3.5371260945749407`*^9, 3.537126224499372*^9}, {
   3.5371312153518324`*^9, 3.5371312189270372`*^9}, {3.53713135938107*^9, 
   3.537131360908158*^9}, 3.5371319261784897`*^9, 3.5371320549248533`*^9, 
   3.537184622746316*^9, {3.537210521005478*^9, 3.537210540514594*^9}, {
   3.5425668658460474`*^9, 3.5425669010050583`*^9}, {3.5431663192027493`*^9, 
   3.5431663670104837`*^9}, 3.5431664675352335`*^9, {3.5431668775976877`*^9, 
   3.543166888507312*^9}, {3.5431671897315407`*^9, 3.5431671989290667`*^9}, 
   3.543172890129585*^9, {3.5432284976379194`*^9, 3.543228521105262*^9}, {
   3.543229817160392*^9, 3.543229835511441*^9}, {3.5432533760808396`*^9, 
   3.543253381831168*^9}, 3.543852642163726*^9, {3.5438572909676228`*^9, 
   3.543857291844673*^9}, {3.5468661795720434`*^9, 3.546866217319203*^9}, 
   3.547428699413786*^9, {3.547506902269785*^9, 3.547506988213701*^9}, {
   3.5478330493625126`*^9, 3.5478330856795893`*^9}, {3.547833334526823*^9, 
   3.547833339626115*^9}, {3.547842821404441*^9, 3.5478428843810434`*^9}, {
   3.5478490682479615`*^9, 3.547849078162529*^9}, 3.5478506104001675`*^9, {
   3.5478508500098724`*^9, 3.5478508557582016`*^9}, 3.5484283806463537`*^9, {
   3.548429097852375*^9, 3.548429109417037*^9}, {3.548429323804299*^9, 
   3.548429327583515*^9}, 3.5487684462193956`*^9, 3.548780263342296*^9, {
   3.548780460360565*^9, 3.5487805441203556`*^9}, {3.54878060643692*^9, 
   3.54878061954767*^9}, {3.548780676408922*^9, 3.5487807444368134`*^9}, {
   3.548780847667718*^9, 3.548780873487194*^9}, {3.548781421033512*^9, 
   3.548781421496539*^9}, {3.5493800747133274`*^9, 3.5493800953055058`*^9}, {
   3.5493801528887987`*^9, 3.549380261078987*^9}, {3.549386934260671*^9, 
   3.549386961028202*^9}, {3.5493870636990747`*^9, 3.5493870641851025`*^9}, {
   3.549387133302056*^9, 3.549387172871319*^9}, {3.549387236473957*^9, 
   3.549387274377125*^9}, {3.5493873687975254`*^9, 3.5493874068947043`*^9}, {
   3.549388190940549*^9, 3.549388202636218*^9}, {3.5493882396723366`*^9, 
   3.5493882932334003`*^9}, {3.5493884555376835`*^9, 3.549388476356874*^9}, {
   3.5493885501590953`*^9, 3.5493885570484896`*^9}, {3.549388679417488*^9, 
   3.5493887152005353`*^9}, 3.5499269959463243`*^9, {3.5499295828782883`*^9, 
   3.549929622891577*^9}, 3.5499321566585*^9, {3.549989124750889*^9, 
   3.549989127310035*^9}, {3.550239562201798*^9, 3.5502395798308067`*^9}, {
   3.5503248695410986`*^9, 3.5503248975367002`*^9}, 3.550427696007436*^9, {
   3.5504277901238194`*^9, 3.5504278401596813`*^9}, {3.5504279841389165`*^9, 
   3.5504281414229126`*^9}, {3.55042836114948*^9, 3.55042836236755*^9}, {
   3.5504283982536025`*^9, 3.550428422691*^9}, {3.55042852129364*^9, 
   3.55042852182167*^9}, {3.5504285610639143`*^9, 3.550428561794956*^9}, {
   3.550434077816455*^9, 3.5504340782904816`*^9}, {3.5504367007964807`*^9, 
   3.5504367012695074`*^9}, {3.550536596283349*^9, 3.550536617885585*^9}, {
   3.550536716144205*^9, 3.550536739278528*^9}, {3.5505370520924196`*^9, 
   3.5505370527004547`*^9}, 3.550580038672138*^9, {3.550580278509856*^9, 
   3.5505802805919747`*^9}, {3.550581088281172*^9, 3.550581093872492*^9}, {
   3.5506221164528494`*^9, 3.55062212047808*^9}, 3.550622258453971*^9, 
   3.550622328957004*^9, {3.5506814206328545`*^9, 3.550681425492132*^9}, 
   3.5506914592710314`*^9, {3.5507039062559586`*^9, 3.5507039259760866`*^9}, {
   3.5507724065394163`*^9, 3.550772411545703*^9}, {3.550772454104137*^9, 
   3.550772551871729*^9}, {3.550772850543812*^9, 3.5507728584032617`*^9}, {
   3.55214359766471*^9, 3.5521436030992537`*^9}, {3.5527593680237503`*^9, 
   3.5527594279787455`*^9}, {3.5527600223521767`*^9, 3.552760027425684*^9}, 
   3.5527609525921917`*^9, 3.5533474569995346`*^9, 3.5533680116551943`*^9, {
   3.553368058176855*^9, 3.5533681150081053`*^9}, 3.55413858984247*^9, 
   3.5595830826707144`*^9, 3.5602747226942377`*^9, {3.5602750937484612`*^9, 
   3.5602751944752226`*^9}, {3.564335774494768*^9, 3.5643357755338273`*^9}, {
   3.5793062068992186`*^9, 3.579306245673437*^9}, {3.5848950450493345`*^9, 
   3.5848950527657757`*^9}, {3.5963954235966735`*^9, 3.596395424547728*^9}}],

Cell[CellGroupData[{

Cell["Analytic Expressions", "Section",
 CellChangeTimes->{{3.6097027918190775`*^9, 3.609702801148611*^9}, 
   3.6231666433449783`*^9}],

Cell[TextData[{
 "Universal DSM prediction using a three-mode BSW ",
 ButtonBox[Cell[TextData[StyleBox[ButtonBox["6"],
  FontVariations->{"CompatibilityType"->"Superscript"}]], "Citation",
  Editable->False,
  TaggingRules->{CitationData -> "bibl:baumgaertel1990relaxation"}],
  BaseStyle->"Hyperlink",
  ButtonData->"bibl:baumgaertel1990relaxation"],
 " with the parameters {\[Alpha]1,\[Alpha]2,\[Alpha]3}, and {\[Tau]1,\[Tau]2,\
\[Tau]3,\[Tau]4} as functions of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["N", "c"], TraditionalForm]]],
 " only. "
}], "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQB2IQ7RXEk7Hk3yvH+5U2eSDanPtbGYj+Mk2sHERnlzyv
B9E3HDqbQHTU/rkTQHR/+KOJILpu7fqpIDrdr3saiG5qOTEHRD8u+QOmbVoi
nZcCafn/ENqm9n4giK4wfACm/1/OPwCiGVYWgGkWhemly4F0axeElnNQrwPR
81ZB6ORE9nYQ/fg0hK4sW94Don8+gNA1q9pngeg/Ih1g2ujo8oUg+on5CjBt
reixHkS/mQyha+xm3gLRpxdA6M9sXD9AdMzGUz9B9IbpUfwrgLS6djSY1ou0
tgLRy95A6KwMbzsQveMUhP7keiYKRJ96CaE1JoYrfAbSPWURYBoAVRTfKw==

  "]],

Cell[BoxData[{
 RowBox[{"Clear", "[", "GsCFSM", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"GsCFSM", "[", 
   RowBox[{"\[Omega]_", ",", " ", 
    RowBox[{"Nc_", "?", "NumericQ"}]}], "]"}], " ", ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\[Alpha]", ",", "\[Tau]v", ",", 
      RowBox[{"n", "=", "3"}], ",", 
      RowBox[{"alpha1", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0005"}], ",", 
         RowBox[{"-", "0.0205"}]}], "}"}]}], ",", 
      RowBox[{"alpha2", "=", 
       RowBox[{"{", 
        RowBox[{"0.00029", ",", "0.109957"}], "}"}]}], ",", 
      RowBox[{"alpha3", "=", 
       RowBox[{"{", 
        RowBox[{"17.69589", ",", "1.04026", ",", 
         RowBox[{"-", "0.00095677"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"tau1", "=", 
       RowBox[{"{", 
        RowBox[{"0.6288876", ",", "0.119458"}], "}"}]}], ",", 
      RowBox[{"tau2", "=", 
       RowBox[{"{", 
        RowBox[{"1.52508156", ",", "0.02996758796795"}], "}"}]}], ",", 
      RowBox[{"tau3", "=", 
       RowBox[{"{", 
        RowBox[{"3.110954", ",", "0.022615"}], "}"}]}], ",", 
      RowBox[{"tau4", "=", 
       RowBox[{"{", 
        RowBox[{"3.4840295", ",", "0.0142809"}], "}"}]}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[Alpha]", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"alpha1", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "Nc"}], "+", 
         RowBox[{"alpha1", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"alpha2", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "Nc"}], "+", 
         RowBox[{"alpha2", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], ",", 
        RowBox[{
         FractionBox[
          RowBox[{"alpha3", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "Nc"], "+", 
         RowBox[{"alpha3", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "+", 
         RowBox[{
          RowBox[{"alpha3", "[", 
           RowBox[{"[", "3", "]"}], "]"}], "Nc"}]}]}], "}"}]}], ";", 
     RowBox[{"\[Tau]v", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"tau1", "[", 
          RowBox[{"[", "2", "]"}], "]"}], 
         SuperscriptBox["Nc", 
          RowBox[{"tau1", "[", 
           RowBox[{"[", "1", "]"}], "]"}]]}], ",", 
        RowBox[{
         RowBox[{"tau2", "[", 
          RowBox[{"[", "2", "]"}], "]"}], 
         SuperscriptBox["Nc", 
          RowBox[{"tau2", "[", 
           RowBox[{"[", "1", "]"}], "]"}]]}], ",", 
        RowBox[{
         RowBox[{"tau3", "[", 
          RowBox[{"[", "2", "]"}], "]"}], 
         SuperscriptBox["Nc", 
          RowBox[{"tau3", "[", 
           RowBox[{"[", "1", "]"}], "]"}]]}], ",", 
        RowBox[{
         RowBox[{"tau4", "[", 
          RowBox[{"[", "2", "]"}], "]"}], 
         SuperscriptBox["Nc", 
          RowBox[{"tau4", "[", 
           RowBox[{"[", "1", "]"}], "]"}]]}]}], "}"}]}], ";", 
     RowBox[{"I", " ", "\[Omega]", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"i", "=", "1"}], "n"], 
         RowBox[{
          RowBox[{"Gamma", "[", 
           RowBox[{"1", "+", 
            RowBox[{"\[Alpha]", "[", 
             RowBox[{"[", "i", "]"}], "]"}]}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"\[Tau]v", "[", 
               RowBox[{"[", 
                RowBox[{"i", "+", "1"}], "]"}], "]"}], 
              RowBox[{"1", "+", 
               RowBox[{"\[Alpha]", "[", 
                RowBox[{"[", "i", "]"}], "]"}]}]], " ", 
             RowBox[{"Hypergeometric2F1Regularized", "[", 
              RowBox[{"1", ",", 
               RowBox[{"1", "+", 
                RowBox[{"\[Alpha]", "[", 
                 RowBox[{"[", "i", "]"}], "]"}]}], ",", 
               RowBox[{"2", "+", 
                RowBox[{"\[Alpha]", "[", 
                 RowBox[{"[", "i", "]"}], "]"}]}], ",", 
               RowBox[{
                RowBox[{"-", "\[ImaginaryI]"}], " ", 
                RowBox[{"\[Tau]v", "[", 
                 RowBox[{"[", 
                  RowBox[{"i", "+", "1"}], "]"}], "]"}], " ", "\[Omega]"}]}], 
              "]"}]}], "-", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"\[Tau]v", "[", 
               RowBox[{"[", "i", "]"}], "]"}], 
              RowBox[{"1", "+", 
               RowBox[{"\[Alpha]", "[", 
                RowBox[{"[", "i", "]"}], "]"}]}]], " ", 
             RowBox[{"Hypergeometric2F1Regularized", "[", 
              RowBox[{"1", ",", 
               RowBox[{"1", "+", 
                RowBox[{"\[Alpha]", "[", 
                 RowBox[{"[", "i", "]"}], "]"}]}], ",", 
               RowBox[{"2", "+", 
                RowBox[{"\[Alpha]", "[", 
                 RowBox[{"[", "i", "]"}], "]"}]}], ",", 
               RowBox[{
                RowBox[{"-", "\[ImaginaryI]"}], " ", 
                RowBox[{"\[Tau]v", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], " ", "\[Omega]"}]}], 
              "]"}]}]}], ")"}], 
          RowBox[{
           UnderoverscriptBox["\[Product]", 
            RowBox[{"j", "=", "2"}], "i"], 
           SuperscriptBox[
            RowBox[{"\[Tau]v", "[", 
             RowBox[{"[", "j", "]"}], "]"}], 
            RowBox[{
             RowBox[{"\[Alpha]", "[", 
              RowBox[{"[", 
               RowBox[{"j", "-", "1"}], "]"}], "]"}], "-", 
             RowBox[{"\[Alpha]", "[", 
              RowBox[{"[", "j", "]"}], "]"}]}]]}]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"i", "=", "1"}], "n"], 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"\[Tau]v", "[", 
               RowBox[{"[", 
                RowBox[{"i", "+", "1"}], "]"}], "]"}], 
              RowBox[{"\[Alpha]", "[", 
               RowBox[{"[", "i", "]"}], "]"}]], "-", 
             SuperscriptBox[
              RowBox[{"\[Tau]v", "[", 
               RowBox[{"[", "i", "]"}], "]"}], 
              RowBox[{"\[Alpha]", "[", 
               RowBox[{"[", "i", "]"}], "]"}]]}], ")"}], "/", 
           RowBox[{"\[Alpha]", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}], 
          RowBox[{
           UnderoverscriptBox["\[Product]", 
            RowBox[{"j", "=", "2"}], "i"], 
           SuperscriptBox[
            RowBox[{"\[Tau]v", "[", 
             RowBox[{"[", "j", "]"}], "]"}], 
            RowBox[{
             RowBox[{"\[Alpha]", "[", 
              RowBox[{"[", 
               RowBox[{"j", "-", "1"}], "]"}], "]"}], "-", 
             RowBox[{"\[Alpha]", "[", 
              RowBox[{"[", "j", "]"}], "]"}]}]]}]}]}], ")"}]}]}]}]}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.614959495824251*^9, 3.614959496122268*^9}, {
   3.614959526261992*^9, 3.6149596044724655`*^9}, {3.61503130562877*^9, 
   3.6150314903343344`*^9}, 3.6150316974251795`*^9, {3.6150317503512063`*^9, 
   3.615031787057306*^9}, {3.6150318336509705`*^9, 3.6150318640627103`*^9}, {
   3.6150413225176544`*^9, 3.615041324976795*^9}, {3.615222163962019*^9, 
   3.61522220787153*^9}, {3.615305386823094*^9, 3.61530542469426*^9}, {
   3.6156406568534718`*^9, 3.615640669779211*^9}, 3.6156407883609934`*^9, 
   3.6156416723905573`*^9, 3.616372278533555*^9, {3.6190240780026045`*^9, 
   3.6190240799877176`*^9}, 3.619024187078843*^9, 3.6230821288220243`*^9, {
   3.6230822165090394`*^9, 3.6230822996117926`*^9}, {3.6230823367999196`*^9, 
   3.6230823477715473`*^9}, {3.623082387359812*^9, 3.623082451254466*^9}, {
   3.6231677305511627`*^9, 3.623167731686228*^9}, {3.623326841363414*^9, 
   3.623326900928484*^9}},
 Background->GrayLevel[0.85]],

Cell["\<\
Rouse dynamics with a three-mode BSW with the parameters \
{\[Alpha]1,\[Alpha]2,\[Alpha]3}, and {\[Tau]1,\[Tau]2,\[Tau]3,\[Tau]4}. \
\>", "Text",
 CellChangeTimes->{{3.623166784385045*^9, 3.623166833889877*^9}, {
  3.623166903688869*^9, 3.623166904705927*^9}, {3.623166975232961*^9, 
  3.6231669962891655`*^9}, {3.6231670566816196`*^9, 3.623167057665676*^9}, {
  3.623167227009362*^9, 3.6231672823855295`*^9}}],

Cell[BoxData[{
 RowBox[{"Clear", "[", "GsR", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"GsR", "[", "\[Omega]_", "]"}], " ", ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"nR", "=", "3"}], ",", "\[Alpha]R", ",", "\[Tau]vR", ",", "GR", 
      ",", "\[Alpha]1", ",", "\[Alpha]2", ",", "\[Alpha]3", ",", "\[Tau]1", 
      ",", "\[Tau]2", ",", "\[Tau]3", ",", "\[Tau]4", ",", "fitm"}], "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"fitm", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\[Alpha]1", "\[Rule]", "0.64635"}], ",", 
        RowBox[{"\[Alpha]2", "\[Rule]", 
         RowBox[{"-", "0.4959"}]}], ",", 
        RowBox[{"\[Alpha]3", "\[Rule]", 
         RowBox[{"-", "1.2716"}]}], ",", 
        RowBox[{"\[Tau]1", "\[Rule]", "6.313268381616272`*^-9"}], ",", 
        RowBox[{"\[Tau]2", "\[Rule]", "2.181509372282138`*^-7"}], ",", 
        RowBox[{"\[Tau]3", "\[Rule]", "0.797317365925168`"}], ",", 
        RowBox[{"\[Tau]4", "\[Rule]", "18.201382525250114`"}]}], "}"}]}], ";",
      "\[IndentingNewLine]", 
     RowBox[{"\[Alpha]R", "=", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[Alpha]1", ",", "\[Alpha]2", ",", "\[Alpha]3"}], "}"}], "/.",
        "fitm"}]}], ";", 
     RowBox[{"\[Tau]vR", "=", " ", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[Tau]1", ",", "\[Tau]2", ",", "\[Tau]3", ",", "\[Tau]4"}], 
        "}"}], "/.", "fitm"}]}], ";", 
     RowBox[{"GR", "=", "1942.29"}], ";", 
     RowBox[{"I", " ", "\[Omega]", " ", "GR", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"i", "=", "1"}], "nR"], 
         RowBox[{
          RowBox[{"Gamma", "[", 
           RowBox[{"1", "+", 
            RowBox[{"\[Alpha]R", "[", 
             RowBox[{"[", "i", "]"}], "]"}]}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"\[Tau]vR", "[", 
               RowBox[{"[", 
                RowBox[{"i", "+", "1"}], "]"}], "]"}], 
              RowBox[{"1", "+", 
               RowBox[{"\[Alpha]R", "[", 
                RowBox[{"[", "i", "]"}], "]"}]}]], " ", 
             RowBox[{"Hypergeometric2F1Regularized", "[", 
              RowBox[{"1", ",", 
               RowBox[{"1", "+", 
                RowBox[{"\[Alpha]R", "[", 
                 RowBox[{"[", "i", "]"}], "]"}]}], ",", 
               RowBox[{"2", "+", 
                RowBox[{"\[Alpha]R", "[", 
                 RowBox[{"[", "i", "]"}], "]"}]}], ",", 
               RowBox[{
                RowBox[{"-", "\[ImaginaryI]"}], " ", 
                RowBox[{"\[Tau]vR", "[", 
                 RowBox[{"[", 
                  RowBox[{"i", "+", "1"}], "]"}], "]"}], " ", "\[Omega]"}]}], 
              "]"}]}], "-", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"\[Tau]vR", "[", 
               RowBox[{"[", "i", "]"}], "]"}], 
              RowBox[{"1", "+", 
               RowBox[{"\[Alpha]R", "[", 
                RowBox[{"[", "i", "]"}], "]"}]}]], " ", 
             RowBox[{"Hypergeometric2F1Regularized", "[", 
              RowBox[{"1", ",", 
               RowBox[{"1", "+", 
                RowBox[{"\[Alpha]R", "[", 
                 RowBox[{"[", "i", "]"}], "]"}]}], ",", 
               RowBox[{"2", "+", 
                RowBox[{"\[Alpha]R", "[", 
                 RowBox[{"[", "i", "]"}], "]"}]}], ",", 
               RowBox[{
                RowBox[{"-", "\[ImaginaryI]"}], " ", 
                RowBox[{"\[Tau]vR", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], " ", "\[Omega]"}]}], 
              "]"}]}]}], ")"}], 
          RowBox[{
           UnderoverscriptBox["\[Product]", 
            RowBox[{"j", "=", "2"}], "i"], 
           SuperscriptBox[
            RowBox[{"\[Tau]vR", "[", 
             RowBox[{"[", "j", "]"}], "]"}], 
            RowBox[{
             RowBox[{"\[Alpha]R", "[", 
              RowBox[{"[", 
               RowBox[{"j", "-", "1"}], "]"}], "]"}], "-", 
             RowBox[{"\[Alpha]R", "[", 
              RowBox[{"[", "j", "]"}], "]"}]}]]}]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"i", "=", "1"}], "nR"], 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"\[Tau]vR", "[", 
               RowBox[{"[", 
                RowBox[{"i", "+", "1"}], "]"}], "]"}], 
              RowBox[{"\[Alpha]R", "[", 
               RowBox[{"[", "i", "]"}], "]"}]], "-", 
             SuperscriptBox[
              RowBox[{"\[Tau]vR", "[", 
               RowBox[{"[", "i", "]"}], "]"}], 
              RowBox[{"\[Alpha]R", "[", 
               RowBox[{"[", "i", "]"}], "]"}]]}], ")"}], "/", 
           RowBox[{"\[Alpha]R", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}], 
          RowBox[{
           UnderoverscriptBox["\[Product]", 
            RowBox[{"j", "=", "2"}], "i"], 
           SuperscriptBox[
            RowBox[{"\[Tau]vR", "[", 
             RowBox[{"[", "j", "]"}], "]"}], 
            RowBox[{
             RowBox[{"\[Alpha]R", "[", 
              RowBox[{"[", 
               RowBox[{"j", "-", "1"}], "]"}], "]"}], "-", 
             RowBox[{"\[Alpha]R", "[", 
              RowBox[{"[", "j", "]"}], "]"}]}]]}]}]}], ")"}]}]}]}]}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.6110759924841037`*^9, 3.61107605483667*^9}, 
   3.611077049729574*^9, 3.611151178399065*^9, {3.6230820760650063`*^9, 
   3.6230820783541374`*^9}, 3.6230824655312824`*^9, {3.6230824981321473`*^9, 
   3.623082585514145*^9}, {3.6233270439814005`*^9, 3.623327093394438*^9}, {
   3.6308970650208664`*^9, 3.630897101387946*^9}},
 Background->GrayLevel[0.85]],

Cell[TextData[{
 "This is an internal function to ",
 StyleBox["GsT",
  FontSlant->"Italic"],
 " to find the low-frequency crossover of the experimental data."
}], "Text",
 CellChangeTimes->{{3.6230845111112833`*^9, 3.623084535199661*^9}, {
  3.6230848622963696`*^9, 3.6230848740720434`*^9}}],

Cell[BoxData[{
 RowBox[{"Clear", "[", "Gslfx", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Gslfx", "[", 
   RowBox[{"expdata_", ",", 
    RowBox[{"\[Omega]guess_", "?", "NumericQ"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "\[Omega]", ",", "Gp", ",", "Gdp", ",", "GpI", ",", "GdpI", ",", 
      "tandelta", ",", "sol"}], "}"}], ",", 
    RowBox[{
     RowBox[{"Gp", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", 
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "/", "1000"}]}], "}"}], "&"}], "/@",
        "expdata"}]}], ";", 
     RowBox[{"Gdp", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", 
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", "3", "]"}], "]"}], "/", "1000"}]}], "}"}], "&"}], "/@",
        "expdata"}]}], ";", 
     RowBox[{"GpI", "=", 
      RowBox[{"Interpolation", "[", 
       RowBox[{"Gp", ",", 
        RowBox[{"InterpolationOrder", "\[Rule]", "1"}]}], "]"}]}], ";", 
     RowBox[{"GdpI", "=", 
      RowBox[{"Interpolation", "[", 
       RowBox[{"Gdp", ",", 
        RowBox[{"InterpolationOrder", "\[Rule]", "1"}]}], "]"}]}], ";", 
     RowBox[{"tandelta", "=", 
      RowBox[{
       RowBox[{"GdpI", "[", "\[Omega]", "]"}], "/", 
       RowBox[{"GpI", "[", "\[Omega]", "]"}]}]}], ";", 
     RowBox[{"sol", "=", 
      RowBox[{"\[Omega]", "/.", 
       RowBox[{"FindRoot", "[", 
        RowBox[{
         RowBox[{"tandelta", "==", "1"}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Omega]", ",", "\[Omega]guess"}], "}"}]}], "]"}]}]}], ";", 
     RowBox[{"{", 
      RowBox[{"sol", ",", 
       RowBox[{"GpI", "[", "sol", "]"}]}], "}"}]}]}], "]"}]}]}], "Input",
 CellChangeTimes->{
  3.6097029094958076`*^9, {3.623082839495672*^9, 3.623082841531789*^9}},
 Background->GrayLevel[0.85]],

Cell[TextData[{
 "Full ",
 StyleBox["G",
  FontSlant->"Italic"],
 "* function generates a prediction over the range of frequencies from the \
terminal zone through the high-frequency crossover. The user inputs the Mw of \
the polymer, the density, \[Rho](T), temperature, T, the ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
    "molecular", " ", "weight", " ", "of", " ", "a", " ", "Kuhn", " ", 
     "step"}], ",", " ", 
    SubscriptBox["M", "K"]}], TraditionalForm]]],
 ", and a rough guess for the low-frequency crossover of the experimental \
data. The function calculates ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["N", "c"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[Tau]", "c"], "from", " ", "the", " ", "low"}], "-", 
    RowBox[{"frequency", " ", "crossover", " ", "of", " ", "the"}]}], 
   TraditionalForm]]],
 " experimental data. The parameters \[Beta] and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Tau]", "K"], TraditionalForm]]],
 " are also calculated. The resulting full DSM G* prediction output is based \
on a separation of time scales argument: ",
 StyleBox["G",
  FontSlant->"Italic"],
 "* = ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubsuperscriptBox["G", "CFSM", "*"], "+"}], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["G", "Rouse", "*"], TraditionalForm]]],
 ". The funciton also returns the parameters ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["M", "c"], ",", " ", 
     SubscriptBox["N", "c"], ",", 
     SubscriptBox["\[Tau]", "c"], ",", " ", "\[Beta]", ",", " ", 
     SubscriptBox["\[Tau]", "K"], ",", " ", 
     RowBox[{"and", " ", 
      SubscriptBox["N", "K"]}]}]}], TraditionalForm]]],
 ") of the model and the low-frequency crossover coordinate, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Omega]", "x"], ",", 
     SubscriptBox["G", "x"]}]}], TraditionalForm]]],
 ")."
}], "Text",
 CellChangeTimes->{{3.623083830206338*^9, 3.6230840148308973`*^9}, {
   3.623084076919449*^9, 3.6230841029109354`*^9}, {3.6230843350802145`*^9, 
   3.623084479952501*^9}, {3.6230845817123213`*^9, 3.6230847725452366`*^9}, {
   3.6230848069412036`*^9, 3.623084851584757*^9}, 3.623085879162531*^9, {
   3.6231673767949295`*^9, 3.6231675420583816`*^9}, {3.623167574810255*^9, 
   3.623167623012012*^9}, {3.6231678015952263`*^9, 3.623167901338931*^9}, {
   3.623167962227414*^9, 3.6231681007223353`*^9}, {3.6231681760426435`*^9, 
   3.623168298554651*^9}, {3.6231683510026503`*^9, 3.623168531698986*^9}, {
   3.6231686539869804`*^9, 3.6231686684698086`*^9}, {3.6231687051549067`*^9, 
   3.623168777043019*^9}, {3.6231695404946856`*^9, 3.623169540508686*^9}, {
   3.6231730377227154`*^9, 3.6231730377367163`*^9}, {3.623173106226634*^9, 
   3.623173106240635*^9}, {3.6231731772306952`*^9, 3.6231731772446957`*^9}, {
   3.623173222233269*^9, 3.62317322224727*^9}, {3.6231733332396183`*^9, 
   3.623173333253619*^9}, {3.623173390242879*^9, 3.6231733902558794`*^9}, {
   3.6231734992541137`*^9, 3.623173499268114*^9}, {3.623173552217143*^9, 
   3.6231736261673727`*^9}, {3.6231736822455807`*^9, 
   3.6231736822455807`*^9}, {3.6231737184466505`*^9, 3.623173753200639*^9}, {
   3.623173785935511*^9, 3.6231738458009353`*^9}, {3.6231739146078706`*^9, 
   3.623173973319229*^9}}],

Cell[BoxData[{
 RowBox[{"Clear", "[", "GsT", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"GsT", "[", 
   RowBox[{"\[Omega]rang_", ",", " ", 
    RowBox[{"MW_", "?", "NumericQ"}], ",", 
    RowBox[{"\[Rho]_", "?", "NumericQ"}], ",", 
    RowBox[{"T_", "?", "NumericQ"}], ",", 
    RowBox[{"MK_", "?", "NumericQ"}], ",", "expdata_", ",", 
    RowBox[{"\[Omega]guess_", "?", "NumericQ"}]}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "\[Omega]", ",", "CFSM", ",", "Rouse", ",", "Gc", ",", "Nc", ",", 
      "\[Tau]c", ",", "\[Beta]", ",", "\[Tau]K", ",", "NK", ",", 
      RowBox[{"R", "=", 
       RowBox[{"8.3145", 
        RowBox[{"(", 
         SuperscriptBox["10", "3"], ")"}]}]}], ",", "sampl", ",", "sol", ",", 
      "solNc", ",", "Ncv", ",", "GxGN0"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"GxGN0", "=", 
      RowBox[{"{", 
       RowBox[{
       "9.191488", ",", "2336.3116", ",", "14232.0515", ",", "33.81303697", 
        ",", "13102.47993", ",", "1068.7744"}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"sol", "=", 
      RowBox[{"Gslfx", "[", 
       RowBox[{"expdata", ",", "\[Omega]guess"}], "]"}]}], ";", 
     RowBox[{"Gc", "=", 
      RowBox[{"sol", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"solNc", "=", 
      RowBox[{"NSolve", "[", 
       RowBox[{
        RowBox[{
         FractionBox[
          RowBox[{
           FractionBox["MW", 
            RowBox[{"\[Rho]", " ", "R", " ", 
             RowBox[{"(", 
              RowBox[{"T", "+", "273.15"}], ")"}]}]], "  ", "Gc"}], 
          RowBox[{
           FractionBox["1", "2"], 
           RowBox[{"(", 
            RowBox[{"Ncv", "-", "3"}], ")"}]}]], "\[Equal]", 
         FractionBox[
          RowBox[{
           RowBox[{"GxGN0", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "+", 
           RowBox[{
            RowBox[{"GxGN0", "[", 
             RowBox[{"[", "2", "]"}], "]"}], 
            SuperscriptBox["Ncv", 
             RowBox[{"-", "1"}]]}], "+", 
           RowBox[{
            RowBox[{"GxGN0", "[", 
             RowBox[{"[", "3", "]"}], "]"}], 
            SuperscriptBox["Ncv", 
             RowBox[{"-", "2"}]]}]}], 
          RowBox[{
           RowBox[{"GxGN0", "[", 
            RowBox[{"[", "4", "]"}], "]"}], "+", 
           RowBox[{
            RowBox[{"GxGN0", "[", 
             RowBox[{"[", "5", "]"}], "]"}], 
            SuperscriptBox["Ncv", 
             RowBox[{"-", "1"}]]}], "+", 
           RowBox[{
            RowBox[{"GxGN0", "[", 
             RowBox[{"[", "6", "]"}], "]"}], 
            SuperscriptBox["Ncv", 
             RowBox[{"-", "2"}]]}]}]]}], ",", "Ncv"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Nc", "=", 
      RowBox[{
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{"Ncv", "/.", "solNc"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"#", ">", "0"}], "&&", 
           RowBox[{"#", "\[Element]", "Reals"}]}], "&"}]}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"\[Tau]c", "=", 
      FractionBox["151.148", 
       RowBox[{
        RowBox[{"sol", "[", 
         RowBox[{"[", "1", "]"}], "]"}], 
        SuperscriptBox["Nc", "3.50"]}]]}], ";", 
     RowBox[{"\[Beta]", "=", 
      RowBox[{
       FractionBox["MW", 
        RowBox[{"0.56", "Nc", " ", "MK"}]], "-", "1"}]}], ";", " ", 
     RowBox[{"\[Tau]K", "=", 
      FractionBox["\[Tau]c", 
       RowBox[{"0.265", " ", 
        SuperscriptBox["\[Beta]", 
         RowBox[{"8", "/", "3"}]]}]]}], ";", 
     RowBox[{"NK", "=", 
      FractionBox["MW", "MK"]}], ";", "\[IndentingNewLine]", 
     RowBox[{"sampl", "=", 
      RowBox[{
       RowBox[{"Reap", "[", 
        RowBox[{"LogLogPlot", "[", 
         RowBox[{"1", ",", 
          RowBox[{"{", 
           RowBox[{"\[Omega]", ",", 
            RowBox[{"\[Omega]rang", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", 
            RowBox[{"\[Omega]rang", "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], "}"}], ",", 
          RowBox[{"MaxRecursion", "\[Rule]", "0"}], ",", 
          RowBox[{"EvaluationMonitor", "\[RuleDelayed]", 
           RowBox[{"Sow", "[", "\[Omega]", "]"}]}]}], "]"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"2", ",", "1"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"CFSM", "=", 
      RowBox[{
       RowBox[{
        RowBox[{
         FractionBox[
          RowBox[{"\[Rho]", " ", "R", " ", 
           RowBox[{"(", 
            RowBox[{"T", "+", "273.15"}], ")"}]}], "MW"], 
         FractionBox["1", "2"], 
         RowBox[{"(", 
          RowBox[{"Nc", "-", "3"}], ")"}], 
         RowBox[{"GsCFSM", "[", 
          RowBox[{
           RowBox[{"#", "*", "\[Tau]c"}], ",", "Nc"}], "]"}]}], "&"}], "/@", 
       "sampl"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Rouse", "=", 
      RowBox[{
       RowBox[{
        RowBox[{
         FractionBox[
          RowBox[{"\[Rho]", " ", "R", " ", 
           RowBox[{"(", 
            RowBox[{"T", "+", "273.15"}], ")"}]}], "MW"], 
         RowBox[{"(", 
          FractionBox[
           RowBox[{"NK", "+", "\[Beta]"}], 
           RowBox[{"\[Beta]", "+", "1"}]], ")"}], 
         RowBox[{"GsR", "[", 
          RowBox[{"#", "*", "\[Tau]K", " ", "*", 
           SuperscriptBox["\[Beta]", "2"]}], "]"}]}], "&"}], "/@", 
       "sampl"}]}], ";", 
     RowBox[{"Append", "[", 
      RowBox[{
       RowBox[{"MapThread", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{"#1", ",", 
            RowBox[{
             RowBox[{"Re", "[", "#2", "]"}], "+", 
             RowBox[{"Re", "[", "#3", "]"}]}], ",", 
            RowBox[{
             RowBox[{"Im", "[", "#2", "]"}], "+", 
             RowBox[{"Im", "[", "#3", "]"}]}]}], "}"}], "&"}], ",", 
         RowBox[{"{", 
          RowBox[{"sampl", ",", "CFSM", ",", "Rouse"}], "}"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"sol", "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", "Gc", ",", 
         RowBox[{"MW", "/", "Nc"}], ",", "Nc", ",", "\[Tau]c", ",", "\[Beta]",
          ",", "\[Tau]K", ",", "NK"}], "}"}]}], "]"}]}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.594061020693131*^9, 3.5940610215621805`*^9}, {
   3.5940613384853077`*^9, 3.594061339556369*^9}, {3.594138114360795*^9, 
   3.5941381318287935`*^9}, {3.5941432266271996`*^9, 
   3.5941432323795285`*^9}, {3.5941435876938515`*^9, 
   3.5941436035497584`*^9}, {3.594143633756486*^9, 3.594143747046966*^9}, {
   3.594143858153321*^9, 3.594143858770356*^9}, {3.594144265448617*^9, 
   3.5941442718389826`*^9}, {3.594145129074013*^9, 3.5941451527633686`*^9}, {
   3.5941454637311544`*^9, 3.594145464843218*^9}, {3.5944096835711975`*^9, 
   3.59440969899408*^9}, {3.5944097295948305`*^9, 3.594409735923192*^9}, {
   3.5944097870471163`*^9, 3.5944098565800934`*^9}, {3.5944100171062746`*^9, 
   3.5944100252097387`*^9}, {3.5944100841281085`*^9, 3.59441012856765*^9}, {
   3.5944109870737543`*^9, 3.5944109927750797`*^9}, {3.5944111737204294`*^9, 
   3.5944111781956854`*^9}, {3.5944119106165776`*^9, 
   3.5944119145338016`*^9}, {3.594412090085842*^9, 3.5944120907438803`*^9}, {
   3.594412137011526*^9, 3.5944121846342506`*^9}, {3.5944123900650005`*^9, 
   3.594412469620551*^9}, {3.594413086656843*^9, 3.5944131274871783`*^9}, {
   3.5950069901518974`*^9, 3.5950070183785114`*^9}, {3.5950070503913426`*^9, 
   3.5950070660812397`*^9}, {3.5950071396764493`*^9, 
   3.5950071501860504`*^9}, {3.595007217856921*^9, 3.595007308424101*^9}, {
   3.595007484038146*^9, 3.5950074883133907`*^9}, {3.5950079853598194`*^9, 
   3.595008004829933*^9}, {3.595008568019146*^9, 3.5950085938426228`*^9}, {
   3.5950127201166325`*^9, 3.5950127209746814`*^9}, {3.595270406868332*^9, 
   3.5952704092414675`*^9}, {3.5952716973191414`*^9, 3.59527169782617*^9}, {
   3.59527177492158*^9, 3.595271792829604*^9}, {3.595271923488077*^9, 
   3.595271929211405*^9}, {3.595272012748183*^9, 3.5952720219867115`*^9}, {
   3.595274497004274*^9, 3.5952745193525524`*^9}, {3.5952746741024036`*^9, 
   3.5952746759985123`*^9}, {3.5952751498446145`*^9, 3.595275156081971*^9}, {
   3.595275672264495*^9, 3.595275686116287*^9}, 3.5952757890191727`*^9, {
   3.5952758297355022`*^9, 3.595275843914313*^9}, {3.5952758864867477`*^9, 
   3.595275898485434*^9}, {3.595275943817027*^9, 3.595275946067156*^9}, {
   3.5952760012543125`*^9, 3.59527600402147*^9}, {3.5952760380974197`*^9, 
   3.595276040097534*^9}, {3.5952761409173*^9, 3.5952761427864075`*^9}, {
   3.595276324814819*^9, 3.5952763351094074`*^9}, {3.5952769039929457`*^9, 
   3.595276905132011*^9}, {3.59527694812147*^9, 3.5952769863156548`*^9}, {
   3.595277039224681*^9, 3.595277054760569*^9}, {3.5952771471708546`*^9, 
   3.59527714918797*^9}, {3.5952771848440094`*^9, 3.5952771875461645`*^9}, {
   3.5953608504724593`*^9, 3.595360856360796*^9}, {3.5953615640862756`*^9, 
   3.595361564974326*^9}, {3.5953616080877924`*^9, 3.595361609467871*^9}, {
   3.595605878146819*^9, 3.5956058986499915`*^9}, {3.595606744435624*^9, 
   3.5956067456026907`*^9}, {3.595606854067895*^9, 3.595606889889944*^9}, {
   3.5956069368716307`*^9, 3.5956069984031506`*^9}, {3.595607046942927*^9, 
   3.5956070566924844`*^9}, {3.5956071041802006`*^9, 3.595607105763291*^9}, 
   3.5956071496057987`*^9, {3.595607184128773*^9, 3.5956071973485293`*^9}, {
   3.5956072400859737`*^9, 3.595607306295761*^9}, {3.5956076192876625`*^9, 
   3.595607837517145*^9}, {3.5956080490262423`*^9, 3.595608060008871*^9}, {
   3.595608094455841*^9, 3.595608154100252*^9}, 3.5956082637405233`*^9, {
   3.5956083924378843`*^9, 3.5956085074054604`*^9}, {3.5956086273993235`*^9, 
   3.5956087232478056`*^9}, {3.5956087555976562`*^9, 
   3.5956087954319344`*^9}, {3.5956110097473297`*^9, 3.595611015412654*^9}, 
   3.595611965963022*^9, {3.5956130575824594`*^9, 3.5956130661419487`*^9}, {
   3.595613408685541*^9, 3.5956134149018965`*^9}, {3.595613828258539*^9, 
   3.59561383911316*^9}, {3.595615052225546*^9, 3.595615053505619*^9}, {
   3.595615344533265*^9, 3.595615353215762*^9}, {3.5956160938631244`*^9, 
   3.595616107980932*^9}, {3.595617255159547*^9, 3.5956172566426315`*^9}, {
   3.5956174608603125`*^9, 3.5956174759961777`*^9}, {3.5956181735260744`*^9, 
   3.5956181762022276`*^9}, {3.59561890268478*^9, 3.595618902830788*^9}, {
   3.595620616618811*^9, 3.5956206289295154`*^9}, {3.5956339279359455`*^9, 
   3.595633959537753*^9}, {3.5956340057873983`*^9, 3.5956340099906387`*^9}, {
   3.5956343319260526`*^9, 3.595634346097863*^9}, {3.5956350649089766`*^9, 
   3.5956350670921016`*^9}, {3.595636382743353*^9, 3.595636399743325*^9}, {
   3.595637801230486*^9, 3.5956378168653793`*^9}, 3.5956387404352045`*^9, {
   3.5956435848992925`*^9, 3.5956435873554325`*^9}, {3.595644478217387*^9, 
   3.595644483470688*^9}, {3.59564875595606*^9, 3.595648763511492*^9}, {
   3.595650964755396*^9, 3.5956509788142004`*^9}, {3.595654104971006*^9, 
   3.5956541133534856`*^9}, {3.5956895580988703`*^9, 3.595689644736826*^9}, {
   3.5957439501434507`*^9, 3.5957439534364557`*^9}, {3.5957441135596857`*^9, 
   3.595744141844726*^9}, {3.595744183375786*^9, 3.5957442160778327`*^9}, {
   3.5957442461898766`*^9, 3.5957443912660866`*^9}, {3.5957445838413625`*^9, 
   3.59574460314439*^9}, {3.595766715000678*^9, 3.5957667913130426`*^9}, {
   3.5957965050262036`*^9, 3.5957965142597313`*^9}, {3.595796558521263*^9, 
   3.595796657982952*^9}, {3.5957967947427745`*^9, 3.5957968008851256`*^9}, {
   3.595796876632458*^9, 3.5957970913517394`*^9}, {3.5957971231735597`*^9, 
   3.5957971590976143`*^9}, {3.595797256367178*^9, 3.595797305976015*^9}, {
   3.595797376832068*^9, 3.5957973913188963`*^9}, {3.595819001919747*^9, 
   3.5958190035421495`*^9}, {3.595844548705823*^9, 3.5958445527980576`*^9}, {
   3.5958940159510927`*^9, 3.595894023342515*^9}, {3.595894284477828*^9, 
   3.595894291903441*^9}, {3.5958943531959486`*^9, 3.595894356690355*^9}, {
   3.595894400682432*^9, 3.5958944312428856`*^9}, 3.5959005484339066`*^9, 
   3.595900778772081*^9, {3.595901802355626*^9, 3.5959018272470503`*^9}, {
   3.5959018631281023`*^9, 3.5959018692454524`*^9}, 3.595901949351034*^9, {
   3.5959022174143667`*^9, 3.595902217703383*^9}, {3.595905916455485*^9, 
   3.5959059265487022`*^9}, {3.595956109836671*^9, 3.595956138303299*^9}, {
   3.5959561832788715`*^9, 3.5959562243462205`*^9}, 3.5959563980771575`*^9, 
   3.5959567766488104`*^9, {3.5959571927656107`*^9, 3.595957193990681*^9}, {
   3.595958635119109*^9, 3.5959586582014294`*^9}, {3.5962145220063734`*^9, 
   3.596214606963233*^9}, {3.5962161732368183`*^9, 3.596216248429119*^9}, {
   3.5962167667517653`*^9, 3.5962167910521555`*^9}, {3.596221025365344*^9, 
   3.596221034449864*^9}, {3.5962210659026628`*^9, 3.596221123564961*^9}, {
   3.5962211718057203`*^9, 3.596221171946728*^9}, 3.596221205154628*^9, {
   3.596221244656887*^9, 3.59622124541193*^9}, {3.5962213042472954`*^9, 
   3.5962213188341293`*^9}, {3.5962213801766386`*^9, 
   3.5962213810716896`*^9}, {3.5962218312594385`*^9, 3.596221871032714*^9}, {
   3.5962219248967943`*^9, 3.596221928020973*^9}, {3.5962233466011114`*^9, 
   3.596223359880871*^9}, {3.59622342245245*^9, 3.596223433577086*^9}, {
   3.596223939341014*^9, 3.596223943079228*^9}, {3.5962245511340065`*^9, 
   3.596224566123864*^9}, {3.5962253786963406`*^9, 3.596225392884152*^9}, {
   3.596385920505128*^9, 3.596385978971472*^9}, {3.596386014798521*^9, 
   3.596386022314951*^9}, {3.5963861169413633`*^9, 3.596386129013054*^9}, {
   3.596386219738243*^9, 3.5963862213113327`*^9}, {3.5963867888287935`*^9, 
   3.5963867979313135`*^9}, {3.5963868861683607`*^9, 3.596386890451606*^9}, {
   3.5963874991254196`*^9, 3.596387502555616*^9}, {3.596387573169655*^9, 
   3.5963875807760897`*^9}, {3.596387637893357*^9, 3.5963876582715225`*^9}, {
   3.596388517530669*^9, 3.5963885309404364`*^9}, {3.596391517511258*^9, 
   3.5963915334931726`*^9}, {3.5963934814585896`*^9, 3.596393493824297*^9}, {
   3.5963957958019624`*^9, 3.5963958359642596`*^9}, {3.5963963196839266`*^9, 
   3.596396338462001*^9}, {3.5963999571939807`*^9, 3.596399974161951*^9}, {
   3.5964102727008195`*^9, 3.596410275691991*^9}, {3.596410565346558*^9, 
   3.5964105678397007`*^9}, {3.5964108153568583`*^9, 
   3.5964108265044956`*^9}, {3.596410985632597*^9, 3.5964109880217338`*^9}, {
   3.5964111404894543`*^9, 3.596411143921651*^9}, {3.5964131676514015`*^9, 
   3.596413178974049*^9}, {3.5964133498038197`*^9, 3.596413359142354*^9}, {
   3.5988055707818813`*^9, 3.5988056206557336`*^9}, 3.5988062892049723`*^9, {
   3.5988063192506905`*^9, 3.5988063215198207`*^9}, {3.5988065029231963`*^9, 
   3.5988065032022123`*^9}, {3.598890849374482*^9, 3.598890850824565*^9}, {
   3.599849516889519*^9, 3.5998495576348495`*^9}, {3.5998497100575676`*^9, 
   3.599849710567597*^9}, {3.599849766935821*^9, 3.599849767128832*^9}, {
   3.599850059922579*^9, 3.599850060396606*^9}, {3.599850500208762*^9, 
   3.599850500645787*^9}, {3.5998505796243043`*^9, 3.59985062046264*^9}, {
   3.600015689644369*^9, 3.6000156992499185`*^9}, {3.60002156552245*^9, 
   3.600021565955475*^9}, 3.6000261599552364`*^9, {3.6000267366012187`*^9, 
   3.600026740069417*^9}, {3.600027618897683*^9, 3.600027646550265*^9}, {
   3.6000279591161423`*^9, 3.600027960452219*^9}, {3.6000280099370494`*^9, 
   3.600028010250067*^9}, {3.6002204945133777`*^9, 3.600220494745391*^9}, {
   3.6002211594954123`*^9, 3.6002211604724684`*^9}, {3.600221318168488*^9, 
   3.600221318538509*^9}, {3.600221389221552*^9, 3.600221391764697*^9}, 
   3.600221448444939*^9, {3.6004440009777093`*^9, 3.6004440305694017`*^9}, {
   3.6004440711067204`*^9, 3.6004440720857763`*^9}, 3.6004466686402907`*^9, {
   3.6004471936253185`*^9, 3.6004471951694064`*^9}, {3.6022741243352213`*^9, 
   3.602274125381281*^9}, {3.602274200115556*^9, 3.6022742688384867`*^9}, {
   3.602274319158365*^9, 3.6022745572089806`*^9}, 3.6022747595605545`*^9, {
   3.6022750177383213`*^9, 3.6022750205264807`*^9}, {3.6022767732487307`*^9, 
   3.602276924450379*^9}, {3.6022770574479856`*^9, 3.602277057823007*^9}, {
   3.6022781017307158`*^9, 3.60227810215974*^9}, {3.60243500357133*^9, 
   3.6024350144819546`*^9}, 3.6025032202083273`*^9, {3.6033160614693403`*^9, 
   3.6033160672423487`*^9}, {3.6033161003153963`*^9, 
   3.6033161305964403`*^9}, {3.603316533061019*^9, 3.6033165342210207`*^9}, {
   3.6033195463303566`*^9, 3.603319550563362*^9}, {3.603319609620447*^9, 
   3.6033196164734573`*^9}, {3.6033225903988485`*^9, 
   3.6033226029205647`*^9}, {3.6033226953798532`*^9, 3.603322706353481*^9}, {
   3.6033229884516163`*^9, 3.603323003855497*^9}, {3.603323052948305*^9, 
   3.603323071530368*^9}, {3.6033231430124564`*^9, 3.603323150134864*^9}, {
   3.606153010820301*^9, 3.6061530344106503`*^9}, 3.606153075081976*^9, {
   3.606155281461174*^9, 3.60615552650819*^9}, {3.606155904895832*^9, 
   3.6061559121882496`*^9}, {3.606155943770056*^9, 3.6061559618370895`*^9}, {
   3.606156068935215*^9, 3.606156157162261*^9}, {3.6061564475838723`*^9, 
   3.6061564781646214`*^9}, 3.60615651240558*^9, {3.6061566100631657`*^9, 
   3.606156648043338*^9}, {3.606158166579193*^9, 3.606158205961446*^9}, 
   3.606158386337763*^9, {3.6061584463881974`*^9, 3.606158451443486*^9}, {
   3.6061585772696834`*^9, 3.606158578047728*^9}, 3.6061586335769043`*^9, {
   3.6066979304454517`*^9, 3.6066980520744085`*^9}, {3.6066980983970585`*^9, 
   3.6066981685990734`*^9}, {3.6066986936991076`*^9, 
   3.6066987054777813`*^9}, {3.6067613795569825`*^9, 
   3.6067613909986367`*^9}, {3.606837364691084*^9, 3.606837371775489*^9}, {
   3.6068374274906754`*^9, 3.606837435751148*^9}, {3.6068390938029833`*^9, 
   3.606839099713321*^9}, {3.606839206763444*^9, 3.606839207305475*^9}, {
   3.606841206023795*^9, 3.6068412950298862`*^9}, {3.606843038175588*^9, 
   3.606843038599612*^9}, {3.6068430853812885`*^9, 3.606843085726308*^9}, {
   3.6068431204662952`*^9, 3.6068431559513245`*^9}, {3.606844563216816*^9, 
   3.6068445719903173`*^9}, {3.6068449318979025`*^9, 
   3.6068450160437155`*^9}, {3.6068452624028068`*^9, 3.606845270095247*^9}, {
   3.606845328743601*^9, 3.606845359167341*^9}, {3.6068454140334797`*^9, 
   3.60684548904377*^9}, {3.606845544048916*^9, 3.6068455532554426`*^9}, {
   3.606845605680441*^9, 3.6068456083775954`*^9}, {3.6068456901842747`*^9, 
   3.606845695073554*^9}, {3.606845751680792*^9, 3.6068457944442377`*^9}, {
   3.60709225920467*^9, 3.6070922601607246`*^9}, {3.607092292561578*^9, 
   3.607092301830108*^9}, {3.6070925409147835`*^9, 3.607092554254546*^9}, {
   3.6070932568187304`*^9, 3.607093257719782*^9}, {3.6071732944613466`*^9, 
   3.607173295326396*^9}, {3.607796958388093*^9, 3.6077970178204927`*^9}, {
   3.6077970499593306`*^9, 3.6077970847123184`*^9}, {3.6077971363782735`*^9, 
   3.6077973631422434`*^9}, {3.6077974693823204`*^9, 
   3.6077975357311153`*^9}, {3.607797600956846*^9, 3.607797622622085*^9}, {
   3.6077977596449223`*^9, 3.6077977657982745`*^9}, {3.6077987826024323`*^9, 
   3.607798799395393*^9}, 3.607799831941451*^9, {3.6078002172794914`*^9, 
   3.607800241010848*^9}, {3.607800416663895*^9, 3.6078004334198537`*^9}, {
   3.6078008779082766`*^9, 3.6078008798583884`*^9}, {3.607800918443595*^9, 
   3.6078009375256867`*^9}, {3.607801641171933*^9, 3.6078017376204495`*^9}, {
   3.607802040812791*^9, 3.6078020458190775`*^9}, {3.6078025929153695`*^9, 
   3.607802725431949*^9}, {3.607802849282033*^9, 3.607802931145715*^9}, {
   3.607803025337103*^9, 3.607803057269929*^9}, {3.607803100791418*^9, 
   3.6078031157952766`*^9}, {3.607803341360178*^9, 3.607803389905955*^9}, {
   3.6078034239379015`*^9, 3.6078034524545326`*^9}, {3.607804039451107*^9, 
   3.607804041808242*^9}, {3.6078043778944645`*^9, 3.607804378280487*^9}, {
   3.6078044112493725`*^9, 3.6078044768161225`*^9}, {3.607804518233492*^9, 
   3.607804521233663*^9}, {3.607804628720811*^9, 3.6078046539712553`*^9}, {
   3.6078048092071342`*^9, 3.6078048100081797`*^9}, {3.607805027821638*^9, 
   3.607805057059311*^9}, {3.607805109441307*^9, 3.607805134432736*^9}, {
   3.6078808264250298`*^9, 3.607880971697339*^9}, {3.6078810157508583`*^9, 
   3.6078811120713673`*^9}, {3.6078811428551283`*^9, 3.60788119865632*^9}, {
   3.6078812755737195`*^9, 3.607881289560519*^9}, {3.6078813275986953`*^9, 
   3.6078813814777765`*^9}, {3.6078814211980486`*^9, 
   3.6078818185027733`*^9}, {3.6078818592261024`*^9, 3.607881920694618*^9}, {
   3.6078820019112635`*^9, 3.6078820567714014`*^9}, {3.6078821725160217`*^9, 
   3.6078822208537865`*^9}, 3.607882430659786*^9, {3.6078837969419336`*^9, 
   3.607883867043943*^9}, {3.607888139132128*^9, 3.607888156702133*^9}, {
   3.6078882851774817`*^9, 3.6078883384525285`*^9}, {3.6078885774701996`*^9, 
   3.607888718378259*^9}, {3.6078887884192653`*^9, 3.607888793604562*^9}, 
   3.607889006400733*^9, {3.607889142662527*^9, 3.6078891862490196`*^9}, 
   3.607889468493163*^9, {3.607889586066888*^9, 3.6078895989646254`*^9}, {
   3.607889662409254*^9, 3.607889684620525*^9}, {3.6078897173983994`*^9, 
   3.6078897958628874`*^9}, {3.607890439891724*^9, 3.6078904660982227`*^9}, {
   3.6078905431096277`*^9, 3.607890546884844*^9}, {3.6078906049411645`*^9, 
   3.6078906111525197`*^9}, 3.6078906479106216`*^9, 3.607890687629894*^9, {
   3.6078907177186146`*^9, 3.607890718457657*^9}, {3.6078908226846185`*^9, 
   3.607890831858143*^9}, {3.607892475509155*^9, 3.6078925863014917`*^9}, {
   3.607892800815761*^9, 3.6078928285413465`*^9}, 3.6078928727988787`*^9, 
   3.607907902853194*^9, {3.6079085716404467`*^9, 3.6079086331979675`*^9}, {
   3.607911688747735*^9, 3.6079117406577044`*^9}, 3.60791259779373*^9, {
   3.6079656623282013`*^9, 3.6079657432478294`*^9}, {3.607965792492646*^9, 
   3.607965835313095*^9}, {3.6079659663255887`*^9, 3.6079659720999193`*^9}, {
   3.607966085805423*^9, 3.6079660897006454`*^9}, 3.607977614628834*^9, {
   3.607977657713298*^9, 3.60797771492257*^9}, 3.608046780871917*^9, 
   3.6083101544365473`*^9, {3.608312105674152*^9, 3.608312176253189*^9}, {
   3.6083155530833325`*^9, 3.608315553453354*^9}, {3.608315661540536*^9, 
   3.6083156617885504`*^9}, 3.608315713920532*^9, 3.6083157506456327`*^9, {
   3.6083171409771547`*^9, 3.608317187364808*^9}, {3.6083392134066467`*^9, 
   3.6083392268704166`*^9}, 3.608341151092476*^9, {3.6086567445617228`*^9, 
   3.6086568294945807`*^9}, {3.6089160865509553`*^9, 3.608916130749483*^9}, 
   3.608916227251003*^9, {3.6089162764608173`*^9, 3.608916280969075*^9}, {
   3.608916683799116*^9, 3.608916691719569*^9}, {3.6089167252224855`*^9, 
   3.608916758818407*^9}, {3.6089168359188166`*^9, 3.608916837481906*^9}, {
   3.6089183335154743`*^9, 3.608918509816558*^9}, {3.6089193007537975`*^9, 
   3.608919543628689*^9}, {3.608919663019518*^9, 3.6089197340065775`*^9}, {
   3.6089197842484517`*^9, 3.608919807633789*^9}, 3.608919890904552*^9, {
   3.6089199319468994`*^9, 3.6089200338967304`*^9}, {3.6089200784182773`*^9, 
   3.6089201445620604`*^9}, {3.6089201970980654`*^9, 3.608920219596352*^9}, {
   3.608920327483523*^9, 3.608920335510982*^9}, {3.608920372212081*^9, 
   3.608920375946295*^9}, 3.6089204260221586`*^9, {3.608920492056936*^9, 
   3.6089205277679787`*^9}, {3.6089205934447346`*^9, 3.60892067815558*^9}, {
   3.60892072133805*^9, 3.6089207345138035`*^9}, {3.6089207973093953`*^9, 
   3.6089208363596287`*^9}, 3.6089208736927643`*^9, 3.608920927659851*^9, {
   3.608921093880358*^9, 3.6089211742429543`*^9}, {3.608921206383793*^9, 
   3.608921331847969*^9}, {3.6089214055141826`*^9, 3.608921505788918*^9}, {
   3.6089215551717424`*^9, 3.6089215645042763`*^9}, {3.608943587955092*^9, 
   3.608943672860949*^9}, {3.60894380489114*^9, 3.6089438068167067`*^9}, {
   3.608948064166184*^9, 3.608948275795437*^9}, 3.608948531917304*^9, {
   3.6089908629129004`*^9, 3.6089908686982317`*^9}, {3.6089909047022905`*^9, 
   3.608990907384444*^9}, {3.608991027016287*^9, 3.6089910437582445`*^9}, {
   3.608996050882635*^9, 3.6089960817434006`*^9}, {3.6089963556840687`*^9, 
   3.608996370767932*^9}, {3.608997434649782*^9, 3.6089974765061765`*^9}, {
   3.609000196584756*^9, 3.609000202117072*^9}, {3.609000233956894*^9, 
   3.6090002413363156`*^9}, {3.60900086924323*^9, 3.609000892661569*^9}, {
   3.609121223184411*^9, 3.609121264159018*^9}, {3.60912131610072*^9, 
   3.6091213856066313`*^9}, {3.6091214469442263`*^9, 3.609121593527629*^9}, {
   3.609121628023752*^9, 3.6091217205152283`*^9}, {3.609121774337431*^9, 
   3.609121783451981*^9}, {3.6091637551195817`*^9, 3.609163757903741*^9}, 
   3.609181687263242*^9, 3.6091817633045907`*^9, {3.609512367445385*^9, 
   3.609512384188343*^9}, {3.6095124159841614`*^9, 3.6095124177052603`*^9}, {
   3.609513563789812*^9, 3.6095136078443317`*^9}, {3.609513914057846*^9, 
   3.6095139385902495`*^9}, {3.6095140317705793`*^9, 
   3.6095140559229603`*^9}, {3.6095143485586987`*^9, 3.609514364812628*^9}, {
   3.609514397033471*^9, 3.609514411088275*^9}, {3.6095144612211423`*^9, 
   3.609514466463442*^9}, {3.6095145277359467`*^9, 3.6095145537114325`*^9}, {
   3.609514585788267*^9, 3.609514593670718*^9}, 3.609514634946079*^9, {
   3.6095146719011927`*^9, 3.6095146877671003`*^9}, 3.6095147462894473`*^9, 
   3.6095148101470995`*^9, {3.6095148764078894`*^9, 3.60951489301884*^9}, {
   3.60951492589172*^9, 3.6095149463868923`*^9}, 3.6095149960297318`*^9, {
   3.6095151375748277`*^9, 3.6095151732198668`*^9}, {3.609515209787958*^9, 
   3.6095152536084642`*^9}, {3.6095152932347307`*^9, 3.609515409297369*^9}, {
   3.6095165752270565`*^9, 3.609516576370122*^9}, {3.609518046847228*^9, 
   3.60951805911593*^9}, {3.609689296063075*^9, 3.6096893138490925`*^9}, {
   3.609689413473791*^9, 3.609689649439287*^9}, {3.609689682428174*^9, 
   3.609689689783595*^9}, {3.6097040984938145`*^9, 3.609704100240915*^9}, {
   3.614972060097886*^9, 3.614972066066228*^9}, {3.614972107351589*^9, 
   3.614972127657751*^9}, {3.6149721813498216`*^9, 3.614972198548805*^9}, {
   3.615031607623043*^9, 3.6150316378077693`*^9}, {3.6150316749258924`*^9, 
   3.6150316781280756`*^9}, {3.6150324130861125`*^9, 
   3.6150324981439776`*^9}, {3.6150325832448454`*^9, 3.615032589786219*^9}, {
   3.6150326344467735`*^9, 3.6150326861737328`*^9}, {3.615032730602274*^9, 
   3.6150327533175726`*^9}, {3.6150328932685776`*^9, 
   3.6150329195270796`*^9}, {3.61503413079636*^9, 3.615034211413971*^9}, {
   3.6150373637522745`*^9, 3.6150374878343716`*^9}, {3.6150376791353135`*^9, 
   3.6150377056648307`*^9}, {3.615037784901363*^9, 3.6150377853243876`*^9}, {
   3.61504134516895*^9, 3.6150413620429153`*^9}, {3.6150576792720327`*^9, 
   3.61505770720263*^9}, {3.6151344745544715`*^9, 3.6151345685928497`*^9}, {
   3.615134671407731*^9, 3.6151346889297333`*^9}, {3.615134903648014*^9, 
   3.6151349358578568`*^9}, {3.6152244714630003`*^9, 3.615224551244563*^9}, {
   3.6152246111099873`*^9, 3.6152247431745415`*^9}, {3.6152248112664356`*^9, 
   3.6152248173287826`*^9}, 3.6152248526598034`*^9, {3.6152251875979605`*^9, 
   3.6152252158815784`*^9}, {3.6152265738932524`*^9, 
   3.6152265810866632`*^9}, {3.615226696500265*^9, 3.615226702254594*^9}, {
   3.615300970822513*^9, 3.615300974798741*^9}, {3.615305749134817*^9, 
   3.6153057539480925`*^9}, {3.6153057856129036`*^9, 3.615305856148938*^9}, {
   3.615305938145628*^9, 3.615305966562253*^9}, {3.6153061108745074`*^9, 
   3.615306184591724*^9}, 3.6153063029944963`*^9, 3.615306442092452*^9, {
   3.6153065925810595`*^9, 3.6153066082129536`*^9}, 3.615306808617416*^9, {
   3.615306855962124*^9, 3.615306889856063*^9}, {3.615307132222925*^9, 
   3.6153071427545276`*^9}, 3.6153071760054293`*^9, {3.615640970277398*^9, 
   3.615641005258399*^9}, 3.615641846680526*^9, {3.615765938708723*^9, 
   3.6157659587948713`*^9}, 3.6157659969460535`*^9, {3.6157669939680805`*^9, 
   3.615766998926364*^9}, {3.61624982980263*^9, 3.6162498302326307`*^9}, {
   3.6162498606951733`*^9, 3.616249897335225*^9}, {3.6162504410710363`*^9, 
   3.6162504486510468`*^9}, {3.6163727327755365`*^9, 3.616372763018266*^9}, {
   3.6164093990905385`*^9, 3.6164094040418215`*^9}, {3.616410290276511*^9, 
   3.6164102956238174`*^9}, {3.6190249759579644`*^9, 
   3.6190249858055277`*^9}, {3.6190250363254175`*^9, 
   3.6190250442008677`*^9}, {3.6190250793428774`*^9, 
   3.6190252380429544`*^9}, {3.619025285463667*^9, 3.619025374281747*^9}, 
   3.6190254104748173`*^9, {3.619025518000967*^9, 3.61902554340142*^9}, {
   3.619025577153351*^9, 3.619025589242042*^9}, {3.6190256491234674`*^9, 
   3.619025655033805*^9}, {3.6190257028765416`*^9, 3.619025703764592*^9}, 
   3.619025742555811*^9, {3.6190258001341047`*^9, 3.6190258302478266`*^9}, {
   3.619025887564105*^9, 3.6190259219030695`*^9}, 3.6190260107641516`*^9, {
   3.6190267551827297`*^9, 3.6190267871105566`*^9}, {3.6190286471979475`*^9, 
   3.6190287095035105`*^9}, {3.6190287996946697`*^9, 3.619028802897853*^9}, {
   3.619029331831106*^9, 3.6190293782807627`*^9}, {3.6190296009975014`*^9, 
   3.6190296233477798`*^9}, {3.6190296937128043`*^9, 
   3.6190296971209993`*^9}, {3.619031823550624*^9, 3.6190318280658827`*^9}, {
   3.6190413082551184`*^9, 3.6190413299573593`*^9}, {3.6190426723541403`*^9, 
   3.619042708958234*^9}, {3.619048259227691*^9, 3.619048358407364*^9}, {
   3.6190917472840652`*^9, 3.6190917548144965`*^9}, {3.6190917961818624`*^9, 
   3.619091832186922*^9}, 3.619091863151693*^9, {3.619092416350334*^9, 
   3.6190924275239735`*^9}, {3.619092527838711*^9, 3.6190925521160994`*^9}, {
   3.6190934059789376`*^9, 3.6190934157354956`*^9}, {3.6191108095418243`*^9, 
   3.6191108308530436`*^9}, {3.6192585211475086`*^9, 
   3.6192585699703007`*^9}, {3.623082808352891*^9, 3.6230828312051983`*^9}, {
   3.623084777786536*^9, 3.6230847797316475`*^9}, {3.623167750549307*^9, 
   3.6231677514593587`*^9}, {3.6233271720580025`*^9, 3.623327191948389*^9}, {
   3.6272385290921497`*^9, 3.62723852922215*^9}, {3.627238669180416*^9, 
   3.6272386846454463`*^9}, {3.6272387493305798`*^9, 3.627238754502591*^9}, {
   3.62723885620679*^9, 3.6272388709618177`*^9}},
 Background->GrayLevel[0.85]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Comparison with experiments based on matching low-frequency crossover between \
G\[CloseCurlyQuote] and G\[CloseCurlyQuote]\[CloseCurlyQuote]\
\>", "Section",
 CellChangeTimes->{{3.609702934492238*^9, 3.6097029590236406`*^9}, {
  3.609703007319403*^9, 3.6097030074144087`*^9}, {3.609774663472153*^9, 
  3.609774664768227*^9}, {3.6231688475950537`*^9, 3.6231688479550743`*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 "Polymer ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["M", 
    StyleBox["W",
     FontSlant->"Plain"]], TraditionalForm]]],
 ", ",
 StyleBox["T",
  FontSlant->"Italic"],
 ", \[Rho], and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["M", 
    StyleBox["K",
     FontSlant->"Plain"]], TraditionalForm]]]
}], "Subsection",
 CellChangeTimes->{{3.6097029752795706`*^9, 3.6097029791867943`*^9}, {
  3.613739792363947*^9, 3.6137397935690155`*^9}, {3.6230831032927604`*^9, 
  3.623083109302104*^9}, {3.62308316290217*^9, 3.623083169686558*^9}, {
  3.623083320823202*^9, 3.6230833499658694`*^9}}],

Cell[TextData[{
 "Enter the ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["M", 
    StyleBox["W",
     FontSlant->"Plain"]], TraditionalForm]]],
 " [Da], T [\[Degree]C], \[Rho](T) ",
 Cell[BoxData[
  FormBox[
   RowBox[{"[", 
    RowBox[{"g", "/", 
     SuperscriptBox["cm", "3"]}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "], and the ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["M", 
     StyleBox["K",
      FontSlant->"Plain"]], "[", "Da", "]"}], TraditionalForm]]]
}], "Text",
 CellChangeTimes->{{3.6230834063190928`*^9, 3.6230834504706182`*^9}, {
   3.6230835094549913`*^9, 3.6230835924757404`*^9}, {3.6231688811709747`*^9, 
   3.6231688947147493`*^9}, {3.6233275797599983`*^9, 
   3.6233276251738653`*^9}, {3.6233277755777187`*^9, 3.623327776609741*^9}, 
   3.6233281411600456`*^9, {3.623328202434719*^9, 3.623328206873814*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Mw", "=", "204000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"T", "=", "30"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Rho]", "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{"T", "+", "273.15"}], ")"}]}], " ", "0.00056"}], "+", 
     "1.0547"}], ")"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Mk", "=", "103.9"}], ";"}], " "}]}], "Input",
 CellChangeTimes->{
  3.60977939883*^9, {3.6116919297621136`*^9, 3.611691972842578*^9}, 
   3.611709061695648*^9, {3.623083617174153*^9, 3.6230836659879446`*^9}, {
   3.6231719003606625`*^9, 3.623171923455983*^9}},
 Background->RGBColor[1, 0.925, 0.925]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Experimental data",
 FontFamily->"Arial",
 FontColor->RGBColor[0., 0., 1.]]], "Subsubsection",
 CellChangeTimes->{{3.6097793876923633`*^9, 3.6097793893394575`*^9}, {
  3.6156415851685686`*^9, 3.6156415861826267`*^9}, {3.623084887192794*^9, 
  3.623084918215568*^9}, {3.6231676887007694`*^9, 3.623167697489272*^9}}],

Cell[TextData[{
 "The experimental data format should be an array of three element data \
points. One for the radial frequency, the second for G\[CloseCurlyQuote] \
[Pa], and the third for G\[CloseCurlyQuote]\[CloseCurlyQuote] [Pa], ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["\[Omega]", "1"], ",", " ", 
      RowBox[{
       RowBox[{"G", "'"}], " ", 
       RowBox[{"(", 
        SubscriptBox["\[Omega]", "1"], ")"}]}], ",", 
      RowBox[{
       RowBox[{"G", "''"}], 
       RowBox[{"(", 
        SubscriptBox["\[Omega]", "1"]}]}]}]}]}], TraditionalForm]]],
 ")},{",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Omega]", "2"], ",", " ", 
    RowBox[{
     RowBox[{"G", "'"}], " ", 
     RowBox[{"(", 
      SubscriptBox["\[Omega]", "2"], ")"}]}], ",", 
    RowBox[{
     RowBox[{"G", "''"}], 
     RowBox[{"(", 
      SubscriptBox["\[Omega]", "2"]}]}]}], TraditionalForm]]],
 ")},....,{",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Omega]", "m"], ",", " ", 
    RowBox[{
     RowBox[{"G", "'"}], " ", 
     RowBox[{"(", 
      SubscriptBox["\[Omega]", "m"], ")"}]}], ",", 
    RowBox[{
     RowBox[{"G", "''"}], 
     RowBox[{"(", 
      SubscriptBox["\[Omega]", "m"]}]}]}], TraditionalForm]]],
 ")}}. The example below is using data by van Ruymbeke",
 StyleBox[" et al",
  FontSlant->"Italic"],
 ". ",
 ButtonBox[Cell[TextData[StyleBox[ButtonBox["7"],
  FontVariations->{"CompatibilityType"->"Superscript"}]], "Citation",
  Editable->False,
  TaggingRules->{CitationData -> "bibl:van2010decoding"}],
  BaseStyle->"Hyperlink",
  ButtonData->"bibl:van2010decoding"]
}], "Text",
 CellChangeTimes->{{3.6230849251839666`*^9, 3.623084928400151*^9}, {
   3.623085409344659*^9, 3.6230854401684217`*^9}, {3.6231676716497936`*^9, 
   3.623167682441411*^9}, {3.6231679160417724`*^9, 3.6231679164997983`*^9}, 
   3.623168935379075*^9, {3.6231690041720095`*^9, 3.6231693156438246`*^9}, {
   3.623169354069023*^9, 3.6231693891560297`*^9}, {3.62316942413203*^9, 
   3.6231694657474103`*^9}, {3.6231695384975715`*^9, 
   3.6231695415047436`*^9}, {3.6231730387227726`*^9, 
   3.6231730387327733`*^9}, {3.6231731072266912`*^9, 
   3.6231731072366915`*^9}, {3.6231731782307525`*^9, 
   3.6231731782407527`*^9}, {3.6231732232333264`*^9, 3.623173223243327*^9}, {
   3.6231733342396755`*^9, 3.6231733342496758`*^9}, {3.623173391242936*^9, 
   3.6231733912529364`*^9}, {3.623173500254171*^9, 3.6231735002641716`*^9}, {
   3.623173846788992*^9, 3.623173846799992*^9}, {3.6231740813134055`*^9, 
   3.623174095326207*^9}, {3.6231742678310738`*^9, 3.6231742678420744`*^9}, {
   3.6231746108546934`*^9, 3.623174610865694*^9}, {3.623174643356553*^9, 
   3.623174643367553*^9}, {3.6231748713835955`*^9, 3.6231748713945956`*^9}, {
   3.623328003736499*^9, 3.6233280037625*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"GsEd", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.011284`", ",", "638.75`", ",", "5934.3`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.020067`", ",", "1223.7`", ",", "10096"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.035684`", ",", "2305.5`", ",", "17194"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.061581`", ",", "4398.8`", ",", "28046"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.10933`", ",", "9389", ",", "48941"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.11284`", ",", "9149.9`", ",", "49462"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.19442`", ",", "19760", ",", "81732"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.20067`", ",", "20016", ",", "82778"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.34574`", ",", "45214", ",", "131850"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.35684`", ",", "45514", ",", "135200"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.61481`", ",", "99043", ",", "200790"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.61737`", ",", "100100", ",", "204540"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.69423`", ",", "118170", ",", "219200"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.0933`", ",", "201370", ",", "269660"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.0978`", ",", "204400", ",", "272000"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.2345`", ",", "232500", ",", "280860"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.7223`", ",", "312480", ",", "301320"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.9474`", ",", "335410", ",", "296520"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.0067`", ",", "345600", ",", "298790"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.6395`", ",", "414760", ",", "287290"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3.4574`", ",", "475580", ",", "286390"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3.4717`", ",", "485650", ",", "282500"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3.9039`", ",", "504610", ",", "279350"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4.6937`", ",", "526200", ",", "277680"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"6.1481`", ",", "585790", ",", "254360"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"6.1737`", ",", "588810", ",", "248670"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"6.9423`", ",", "605530", ",", "245360"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"8.3467`", ",", "626640", ",", "236900"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"10.933`", ",", "673310", ",", "221840"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"10.978`", ",", "677230", ",", "218170"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"14.114`", ",", "692550", ",", "212040"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"17.223`", ",", "733620", ",", "195390"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"19.474`", ",", "745210", ",", "188590"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"21.953`", ",", "758180", ",", "184520"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"26.395`", ",", "775980", ",", "183240"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"34.574`", ",", "808810", ",", "165600"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"39.039`", ",", "817280", ",", "160890"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"46.937`", ",", "815240", ",", "151200"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"54.465`", ",", "851170", ",", "146590"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"61.737`", ",", "861620", ",", "144400"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"79.368`", ",", "873290", ",", "140270"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"86.385`", ",", "880030", ",", "138960"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"109.78`", ",", "910160", ",", "126680"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"141.14`", ",", "919830", ",", "124640"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"153.62`", ",", "923940", ",", "122270"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"195.23`", ",", "951560", ",", "111520"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"250.98`", ",", "960160", ",", "111630"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"273.17`", ",", "965830", ",", "109510"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"390.39`", ",", "994290", ",", "99493"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"469.37`", ",", "1009200", ",", "95464"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"617.37`", ",", "1026900", ",", "90156"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"793.68`", ",", "1030700", ",", "88010"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"863.85`", ",", "1035500", ",", "86912"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1484.3`", ",", "1068000", ",", "77082"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1596.9`", ",", "1064400", ",", "74271"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2731.7`", ",", "1089600", ",", "69396"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4463.2`", ",", "1105000", ",", "65702"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5049.9`", ",", "1113100", ",", "62744"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"8980.1`", ",", "1134100", ",", "60882"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"15969", ",", "1151900", ",", "59509"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"27317", ",", "1166200", ",", "64582"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"48380", ",", "1230800", ",", "52669"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"50499", ",", "1192400", ",", "74694"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"142840", ",", "1188400", ",", "106200"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"159690", ",", "1231000", ",", "119740"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"272060", ",", "1258200", ",", "159190"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"451680", ",", "1292900", ",", "234760"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"504990", ",", "1303300", ",", "252140"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"803220", ",", "1342800", ",", "375730"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"898010", ",", "1368400", ",", "374540"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1428400", ",", "1467700", ",", "561440"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1596900", ",", "1471700", ",", "554580"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2540000", ",", "1641500", ",", "813480"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4224800", ",", "1744400", ",", "1090400"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4838000", ",", "1910900", ",", "1214900"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"8032200", ",", "2261700", ",", "1732600"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"13360000", ",", "2349900", ",", "2220200"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"15067000", ",", "2297000", ",", "2124700"}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Gp", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "/", "1000"}]}], "}"}], "&"}], "/@", 
    "GsEd"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Gdp", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", "3", "]"}], "]"}], "/", "1000"}]}], "}"}], "&"}], "/@", 
    "GsEd"}]}], ";"}], "\n", 
 RowBox[{"GsE", "=", 
  RowBox[{"ListLogLogPlot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"Gp", ",", "Gdp"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"5", " ", 
          SuperscriptBox["10", 
           RowBox[{"-", "3"}]]}], ",", 
         RowBox[{"2", " ", 
          SuperscriptBox["10", "7"]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["10", 
           RowBox[{"-", "1"}]]}], ",", 
         RowBox[{"3", " ", 
          SuperscriptBox["10", "3"]}]}], "}"}]}], "}"}]}], ",", 
    RowBox[{"PlotMarkers", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Style", "[", 
         RowBox[{
         "\"\<\[FilledLeftTriangle]\>\"", ",", "Blue", ",", "Medium"}], "]"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"Style", "[", 
         RowBox[{"\"\<\[LeftTriangle]\>\"", ",", "Blue", ",", "Medium"}], 
         "]"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"Axes", "\[Rule]", "False"}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"FontSize", "\[Rule]", "15"}], ",", 
       RowBox[{"FontFamily", "\[Rule]", "\"\<Arial\>\""}]}], "}"}]}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", "0.7"}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\[Omega], rad/s\>\"", ",", 
       "\"\<\!\(\*SuperscriptBox[\(G\), \(*\)]\), kPa\>\""}], "}"}]}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "490"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{
  3.6090060690946445`*^9, 3.609007413187522*^9, {3.6090074525367727`*^9, 
   3.6090074528877926`*^9}, 3.609060426853839*^9, {3.6090810285187244`*^9, 
   3.609081036004153*^9}, {3.6091654188157396`*^9, 3.609165420273823*^9}, 
   3.609772029487498*^9, {3.6097720854136963`*^9, 3.609772109364066*^9}, {
   3.6097721586528854`*^9, 3.6097722275158243`*^9}, {3.609772291394478*^9, 
   3.6097723162769012`*^9}, {3.609772861967113*^9, 3.6097728717106705`*^9}, {
   3.6097793757166777`*^9, 3.6097793808589725`*^9}, {3.6127211131116276`*^9, 
   3.612721171702979*^9}, {3.621292807489892*^9, 3.621292813417903*^9}, {
   3.6223105248522663`*^9, 3.622310524996275*^9}, {3.6223107115739465`*^9, 
   3.622310711692953*^9}, {3.622310828333625*^9, 3.6223108291826735`*^9}, {
   3.623083676095523*^9, 3.6230836867021294`*^9}, {3.623085359667818*^9, 
   3.623085399642104*^9}, {3.6230854519700975`*^9, 3.623085573771064*^9}, {
   3.623086652355755*^9, 3.623086667237606*^9}, {3.623163467583335*^9, 
   3.623163470101479*^9}, {3.6231635341541424`*^9, 3.6231635400974827`*^9}, {
   3.6231635812318354`*^9, 3.6231636287675543`*^9}, {3.6231664245264626`*^9, 
   3.623166515363658*^9}, {3.6231665663885765`*^9, 3.6231665732599697`*^9}, {
   3.623166688899584*^9, 3.6231666891866*^9}, 3.6231695661721544`*^9, {
   3.623169714229623*^9, 3.623169742081216*^9}, {3.623169896323038*^9, 
   3.6231699566354876`*^9}, {3.6231702532634535`*^9, 
   3.6231702927197104`*^9}, {3.623170652501289*^9, 3.623170657962601*^9}, {
   3.6231708365508156`*^9, 3.62317083714785*^9}, {3.6231709113730955`*^9, 
   3.6231709120751357`*^9}}],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJzt1us/1Hkfx/HBOjTCnM38fuMYMc5soyL9PqgQG1GZSTZKYlNTVnRCpaRU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    "], {
     {Hue[0.67, 0.6, 0.6], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 157], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 158], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 159], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 160], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 161], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 162], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 163], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 164], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 165], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 166], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 167], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 168], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 169], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 170], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 171], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 172], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 173], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 174], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 175], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 176], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 177], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 178], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 179], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 180], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 181], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 182], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 183], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 184], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 185], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 186], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 187], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 188], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 189], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 190], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 191], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 192], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 193], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 194], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 195], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 196], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 197], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 198], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 199], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 200], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 201], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 202], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 203], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 204], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 205], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 206], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 207], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 208], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 209], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 210], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 211], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 212], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 213], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 214], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 215], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 216], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 217], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 218], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 219], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 220], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 221], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 222], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 223], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 224], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 225], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 226], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 227], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 228], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 229], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 230], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 231], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 232], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 233], InsetBox[
       StyleBox["\<\"\[FilledLeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 234]}, 
     {Hue[0.9060679774997897, 0.6, 0.6], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 235], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 236], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 237], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 238], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 239], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 240], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 241], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 242], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 243], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 244], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 245], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 246], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 247], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 248], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 249], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 250], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 251], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 252], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 253], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 254], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 255], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 256], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 257], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 258], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 259], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 260], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 261], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 262], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 263], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 264], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 265], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 266], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 267], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 268], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 269], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 270], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 271], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 272], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 273], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 274], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 275], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 276], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 277], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 278], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 279], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 280], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 281], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 282], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 283], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 284], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 285], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 286], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 287], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 288], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 289], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 290], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 291], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 292], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 293], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 294], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 295], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 296], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 297], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 298], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 299], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 300], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 301], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 302], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 303], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 304], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 305], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 306], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 307], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 308], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 309], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 310], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 311], InsetBox[
       StyleBox["\<\"\[LeftTriangle]\"\>",
        StripOnInput->False,
        LineColor->RGBColor[0, 0, 1],
        FrontFaceColor->RGBColor[0, 0, 1],
        BackFaceColor->RGBColor[0, 0, 1],
        GraphicsColor->RGBColor[0, 0, 1],
        FontSize->Medium,
        FontColor->RGBColor[0, 0, 1]], 312]}, {}}], {}},
  AspectRatio->0.7,
  AxesOrigin->{-5.298317366548036, -1.2039728043259361`},
  BaseStyle->{FontSize -> 15, FontFamily -> "Arial"},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Exp[
       Part[#, 1]], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Exp[
       Part[#, 1]], 
      Exp[
       Part[#, 2]]}& )},
  Frame->True,
  FrameLabel->{{
     FormBox[
     "\"\\!\\(\\*SuperscriptBox[\\(G\\), \\(*\\)]\\), kPa\"", 
      TraditionalForm], None}, {
     FormBox["\"\[Omega], rad/s\"", TraditionalForm], None}},
  FrameTicks->{{{{-2.3025850929940455`, 
       FormBox["0.1`", TraditionalForm]}, {0., 
       FormBox["1", TraditionalForm]}, {2.302585092994046, 
       FormBox["10", TraditionalForm]}, {4.605170185988092, 
       FormBox["100", TraditionalForm]}, {6.907755278982137, 
       FormBox["1000", TraditionalForm]}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659905, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782616`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{-2.3025850929940455`, 
       FormBox["\"\"", TraditionalForm]}, {0., 
       FormBox["\"\"", TraditionalForm]}, {2.302585092994046, 
       FormBox["\"\"", TraditionalForm]}, {4.605170185988092, 
       FormBox["\"\"", TraditionalForm]}, {6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659905, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782616`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}, {{{-4.605170185988091, 
       FormBox["0.01`", TraditionalForm]}, {0., 
       FormBox["1", TraditionalForm]}, {4.605170185988092, 
       FormBox["100", TraditionalForm]}, {9.210340371976184, 
       FormBox[
        TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {13.815510557964274`, 
       FormBox[
        TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {-2.120263536200091, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.4696759700589417`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.07880966137193, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.7985076962177716, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.579818495252942, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.40047756659712525`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2484613592984996, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.11653381625595151`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.4849066497880004`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.1354942159291497`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.5263605246161616`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.8066624897703196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.02535169073515, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.204692619390966, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.356708826689592, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.48863636973214, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.090076835776092, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.7406644019172415`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.131530710604252, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.411832675758411, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.630521876723241, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.809862805379057, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.961879012677683, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.093806555720231, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.695247021764184`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.345834587905333`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.736700896592344`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.017002861746503`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.235692062711331`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.415032991367148`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.567049198665774`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.698976741708323`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{-4.605170185988091, 
       FormBox["\"\"", TraditionalForm]}, {0., 
       FormBox["\"\"", TraditionalForm]}, {4.605170185988092, 
       FormBox["\"\"", TraditionalForm]}, {9.210340371976184, 
       FormBox["\"\"", TraditionalForm]}, {13.815510557964274`, 
       FormBox["\"\"", TraditionalForm]}, {-2.120263536200091, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.4696759700589417`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.07880966137193, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.7985076962177716, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.579818495252942, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.40047756659712525`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2484613592984996, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.11653381625595151`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.4849066497880004`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.1354942159291497`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.5263605246161616`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.8066624897703196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.02535169073515, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.204692619390966, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.356708826689592, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.48863636973214, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.090076835776092, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.7406644019172415`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.131530710604252, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.411832675758411, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.630521876723241, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.809862805379057, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.961879012677683, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.093806555720231, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.695247021764184`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.345834587905333`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.736700896592344`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.017002861746503`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.235692062711331`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.415032991367148`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.567049198665774`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.698976741708323`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}},
  GridLines->{None, None},
  ImageSize->490,
  Method->{},
  PlotRange->{{-5.298317366548036, 
   16.811242831518264`}, {-1.2039728043259361`, 8.006367567650246}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{{{-4.605170185988091, 
      FormBox["0.01`", TraditionalForm]}, {0., 
      FormBox["1", TraditionalForm]}, {4.605170185988092, 
      FormBox["100", TraditionalForm]}, {9.210340371976184, 
      FormBox[
       TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {13.815510557964274`, 
      FormBox[
       TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-2.120263536200091, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.4696759700589417`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.07880966137193, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.7985076962177716, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.579818495252942, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.40047756659712525`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.2484613592984996, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.11653381625595151`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.4849066497880004`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.1354942159291497`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.5263605246161616`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.8066624897703196`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.02535169073515, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.204692619390966, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.356708826689592, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.48863636973214, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.090076835776092, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.7406644019172415`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.131530710604252, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.411832675758411, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.630521876723241, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.809862805379057, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.961879012677683, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.093806555720231, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.695247021764184`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.345834587905333`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.736700896592344`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.017002861746503`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.235692062711331`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.415032991367148`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.567049198665774`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.698976741708323`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, {{-2.3025850929940455`, 
      FormBox["0.1`", TraditionalForm]}, {0., 
      FormBox["1", TraditionalForm]}, {2.302585092994046, 
      FormBox["10", TraditionalForm]}, {4.605170185988092, 
      FormBox["100", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {-1.6094379124341003`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.203972804325936, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.916290731874155, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.6931471805599453, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.5108256237659905, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.35667494393873245`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.2231435513142097, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.10536051565782616`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {0.6931471805599453, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.0986122886681098`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.3862943611198906`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.6094379124341003`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.791759469228055, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.9459101490553132`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.0794415416798357`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.1972245773362196`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.995732273553991, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.4011973816621555`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.6888794541139363`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.912023005428146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.0943445622221, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.248495242049359, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.382026634673881, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.499809670330265, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.298317366548036, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.214608098422191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{{3.6231709571347127`*^9, 3.6231709841432576`*^9}, 
   3.623328079801939*^9, 3.627238687880452*^9, 3.627238759401599*^9, 
   3.6272388745848265`*^9, 3.6297396892541633`*^9, 3.62974245246947*^9, 
   3.6308971249902964`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["DSM Prediction",
 FontFamily->"Arial",
 FontColor->RGBColor[1., 0., 0.]]], "Subsubsection",
 CellChangeTimes->{{3.623085635849614*^9, 3.6230856383527575`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FullGs", "=", 
   RowBox[{"GsT", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       SuperscriptBox["10", 
        RowBox[{"-", "3"}]], ",", 
       RowBox[{"2", " ", 
        SuperscriptBox["10", "10"]}]}], "}"}], ",", "Mw", ",", "\[Rho]", ",", 
     "T", ",", "Mk", ",", "GsEd", ",", "1"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.6089220500610485`*^9, {3.608922323411683*^9, 3.6089223532943926`*^9}, 
   3.608922490798257*^9, {3.608946999470326*^9, 3.608946999641762*^9}, 
   3.6089475503013*^9, 3.608947616934896*^9, 3.609007513455257*^9, 
   3.609007673958437*^9, 3.6090077775263615`*^9, 3.6090078480063925`*^9, 
   3.6095138558255157`*^9, 3.609515958395776*^9, {3.6101915711134377`*^9, 
   3.6101915989410295`*^9}, 3.6190255576172333`*^9, 3.61902603415849*^9, {
   3.6202155016047187`*^9, 3.6202155017127247`*^9}, {3.62021562593383*^9, 
   3.6202156469960346`*^9}, 3.6202164783445845`*^9, 3.620216603179725*^9, {
   3.6230837769902935`*^9, 3.623083787886917*^9}, {3.623085668379475*^9, 
   3.623085679179093*^9}, {3.6230896644230356`*^9, 3.6230896652660837`*^9}, {
   3.6230898118944707`*^9, 3.623089812107483*^9}, {3.6231598332224617`*^9, 
   3.623159834526536*^9}, {3.6231636538979917`*^9, 3.6231636568971634`*^9}, {
   3.6231641660742865`*^9, 3.6231641702505255`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Needs", "[", "\"\<PlotLegends`\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Legend0", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{"\"\<\[FilledUpTriangle]\>\"", ",", "Blue", ",", "Medium"}],
           "]"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{"Style", "[", 
           RowBox[{"\"\<Experiment\>\"", ",", 
            RowBox[{"FontSize", "\[Rule]", "13"}], ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Arial\>\""}]}], "]"}], 
          "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Graphics", "[", 
          RowBox[{"{", 
           RowBox[{"Red", ",", "Thick", ",", 
            RowBox[{"Line", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"0", ",", "0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"2", ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], 
          "]"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{"Style", "[", 
           RowBox[{"\"\<Eq.(14) with Procedure VA\>\"", ",", 
            RowBox[{"FontSize", "\[Rule]", "13"}], ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Arial\>\""}]}], "]"}], 
          "]"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"LegendShadow", "\[Rule]", "False"}], ",", 
     RowBox[{"LegendSize", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "0.2"}], "}"}]}], ",", 
     RowBox[{"LegendPosition", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.28"}], ",", 
        RowBox[{"-", "0.4"}]}], "}"}]}], ",", 
     RowBox[{"LegendTextSpace", "\[Rule]", "4"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FullGsp", "=", 
   RowBox[{"ListLogLogPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", "1", "]"}], "]"}], ",", 
           RowBox[{"#", "[", 
            RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "&"}], "/@", 
        RowBox[{"Drop", "[", 
         RowBox[{"FullGs", ",", 
          RowBox[{"-", "1"}]}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", "1", "]"}], "]"}], ",", 
           RowBox[{"#", "[", 
            RowBox[{"[", "3", "]"}], "]"}]}], "}"}], "&"}], "/@", 
        RowBox[{"Drop", "[", 
         RowBox[{"FullGs", ",", 
          RowBox[{"-", "1"}]}], "]"}]}]}], "}"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"5", " ", 
           SuperscriptBox["10", 
            RowBox[{"-", "3"}]]}], ",", 
          RowBox[{"2", " ", 
           SuperscriptBox["10", "7"]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["10", 
            RowBox[{"-", "1"}]]}], ",", 
          RowBox[{"3", " ", 
           SuperscriptBox["10", "3"]}]}], "}"}]}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Thick", ",", "Red"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Thick", ",", "Red"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"Axes", "\[Rule]", "False"}], ",", 
     RowBox[{"BaseStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontSize", "\[Rule]", "15"}], ",", 
        RowBox[{"FontFamily", "\[Rule]", "\"\<Arial\>\""}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "0.7"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "520"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<\[Omega], rad/s\>\"", ",", 
        "\"\<\!\(\*SuperscriptBox[\(G\), \(*\)]\), kPa\>\""}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"ShowLegend", "[", 
  RowBox[{
   RowBox[{"Show", "[", 
    RowBox[{"FullGsp", ",", "GsE"}], "]"}], ",", "Legend0"}], "]"}]}], "Input",
 CellChangeTimes->{{3.6061530938110476`*^9, 3.606153102399539*^9}, {
   3.6061531568316517`*^9, 3.606153222576412*^9}, {3.60615326658993*^9, 
   3.6061532876001315`*^9}, 3.60615495077626*^9, {3.6061565748491516`*^9, 
   3.606156579847437*^9}, {3.6061585327931395`*^9, 3.6061585646479616`*^9}, {
   3.6061586028321457`*^9, 3.60615862424837*^9}, {3.606158674521246*^9, 
   3.6061586795995364`*^9}, {3.60669827991144*^9, 3.6066983027647476`*^9}, {
   3.6066983975561695`*^9, 3.6066984024434485`*^9}, {3.6066987418038588`*^9, 
   3.606698794639881*^9}, {3.6066998334933*^9, 3.606699835621422*^9}, 
   3.6067444677636833`*^9, {3.6067464073016186`*^9, 3.6067464233005333`*^9}, {
   3.6068423587627277`*^9, 3.606842359897793*^9}, {3.6068438187432337`*^9, 
   3.606843833564082*^9}, {3.6070928899817486`*^9, 3.607092901145387*^9}, {
   3.607092944397861*^9, 3.6070929795318704`*^9}, 3.6070930109956703`*^9, {
   3.6070931343157234`*^9, 3.607093169623743*^9}, {3.607093449466749*^9, 
   3.607093456494151*^9}, {3.6070935517405987`*^9, 3.6070935698216333`*^9}, {
   3.6070937783145585`*^9, 3.607093938576725*^9}, {3.607101403338685*^9, 
   3.6071014103830876`*^9}, {3.607797823664584*^9, 3.607797863611869*^9}, 
   3.6078009737177567`*^9, {3.607801328271036*^9, 3.6078013294731045`*^9}, 
   3.607882510341344*^9, {3.607882598683397*^9, 3.6078826016995697`*^9}, {
   3.607907239192235*^9, 3.607907240468308*^9}, {3.6089226960509973`*^9, 
   3.6089227100717993`*^9}, {3.608923015331259*^9, 3.6089230498662343`*^9}, {
   3.608947360804453*^9, 3.608947406923604*^9}, 3.60894802522001*^9, {
   3.6089910745330043`*^9, 3.6089910899338856`*^9}, {3.6090073954395065`*^9, 
   3.6090073958045278`*^9}, {3.609007570279507*^9, 3.609007572389628*^9}, {
   3.6090077208541193`*^9, 3.6090077573032045`*^9}, {3.6090077875129323`*^9, 
   3.6090077904491005`*^9}, {3.6090078676415153`*^9, 
   3.6090078780331097`*^9}, {3.6090079560975747`*^9, 3.609007965774128*^9}, 
   3.609008035601122*^9, {3.60900840568929*^9, 3.6090084282165785`*^9}, {
   3.609009225025153*^9, 3.609009292698024*^9}, {3.60916532406332*^9, 
   3.609165356606181*^9}, {3.6091654786631627`*^9, 3.609165482846402*^9}, {
   3.609165625198544*^9, 3.609165628380726*^9}, {3.6091666139400716`*^9, 
   3.6091666217035155`*^9}, {3.6091666915615115`*^9, 3.609166695961763*^9}, {
   3.6091832285033956`*^9, 3.6091832525377703`*^9}, {3.6091841308440065`*^9, 
   3.609184131208027*^9}, {3.6095181408236036`*^9, 3.609518179710828*^9}, {
   3.6095182228392944`*^9, 3.609518244208517*^9}, 3.6095182743852425`*^9, {
   3.6097729384824896`*^9, 3.6097729444998336`*^9}, {3.6097743157132626`*^9, 
   3.609774318533424*^9}, {3.609774468527003*^9, 3.609774585877715*^9}, {
   3.6097764812891264`*^9, 3.6097764815921435`*^9}, {3.610996500575157*^9, 
   3.6109965029972954`*^9}, {3.611151850480266*^9, 3.6111518665585814`*^9}, {
   3.611152307863216*^9, 3.6111524179605923`*^9}, {3.6125315465702934`*^9, 
   3.612531560708102*^9}, {3.6125316349253473`*^9, 3.6125317151489353`*^9}, 
   3.612532129350627*^9, {3.6125371621064835`*^9, 3.6125371625605097`*^9}, 
   3.6127464039729853`*^9, 3.614960480444568*^9, 3.616250121383039*^9, 
   3.6163725066326017`*^9, {3.616372585296101*^9, 3.616372588793301*^9}, 
   3.6190254971077724`*^9, 3.619026047285241*^9, {3.6230856941559496`*^9, 
   3.6230857240176573`*^9}, {3.6230860491772556`*^9, 
   3.6230860747937202`*^9}, {3.623086182903904*^9, 3.623086217030856*^9}, {
   3.6230898052660913`*^9, 3.6230898243121805`*^9}, {3.623159675482439*^9, 
   3.623159679615676*^9}, 3.623163644942479*^9, {3.6231641358055553`*^9, 
   3.623164202096347*^9}, {3.623164238157409*^9, 3.62316424201363*^9}, {
   3.623166530375517*^9, 3.623166556762026*^9}, 3.623166697136055*^9, 
   3.6297424487964563`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "obspkg"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(\\\"PlotLegends`\\\"\\)\[NoBreak] is now \
obsolete. The legacy version being loaded may conflict with current \
Mathematica functionality. See the Compatibility Guide for updating \
information.\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6308971258883476`*^9}],

Cell[BoxData[
 GraphicsBox[{InsetBox[
    GraphicsBox[{{{{}, {}, 
        {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJwBQQK+/SFib1JlAgAAACMAAAACAAAAZiAlMpznC8Ahp738eEPzvwuJRBSv
lgnAllrHg3wD5L8PqEl7LFoEwNTI2JfuwOU/qOszvzhs/r/OPhKqsDj/P/Pr
sWL/1PS/jgIve1TdCEB8dnCATt3kv5SuApfxEBFAdOl9E78mp7+kTrBfFpcU
QE3+06isluE/1YMICiL7FkCXnmdnAR/zP4eRbDPhjBhAR9mHn8XB/D808Jwb
Jm4ZQHviz07UmQNAcMFFZTYQGkCSqZBQU7oIQKZnPBylhBpASL7i5F6CDUDN
Sw0PotoaQL9VGO78WBFAYfhLrPQmG0Ap8wezkMQTQDsRhrhAYhtA03x1Kexj
FkCTNLdRYJgbQB1vPWEO9xhATPGW7k/FG0A3CE7i9l0bQIZokhZE6RtAkI3c
FKf4HUBaY3lI4AocQN3cWciOMyBAhuPVjg0mHEBBp/JmrWQhQNZ6JjBwPRxA
xWdK3q+vIkD3gM7K81McQLF7RnqV5CNAAxKmCkJnHEC9hQHvXjMlQHPH123E
exxAGcRpxAt8JkBtZBDV9JAcQN1Vdr6bridAcREMOvymHEDB3UGRD/soQLmD
wDNPwxxADLmxiGYxKkDQXzM3LOQcQKfIzuCgYStAqYm1YD8OHUBizqoRv6ss
QPJm3GSYUh1AhScrZ8DfLUDHyRFr17cdQMh2apWlLS9ADfCJD/9XHkC5DCf0
tjIwQNK1SWAeFh9ANnjvzYzLMEAW55pUVusfQBOqWD5c3TBAMaAdnEIDIEBJ
FPvW
          "]]}, 
        {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAALvedb4qhG8BxD5NN2Ovrv68Bhovz
ORnA/BvkFEle0b/wH/D1lJ4WwEAHYXWGV9g/YZcRF3AvFMBK1xwUwKTvPzKm
2HaEzBHASwU70Mld+T+HkUNKomsOwKj5fPPI2wFAC4lEFK+WCcANChhmFq8G
QA+oSXssWgTAEVwg+0TlC0Co6zO/OGz+v0mP1K54eRBA8+uxYv/U9L8fAQQg
2LwSQHx2cIBO3eS/ecbQ5AvjFEB06X0TvyanvyQ96dQcQxZATf7TqKyW4T9v
qy2NussWQJeeZ2cBH/M/TDYLLIGmFkBH2YefxcH8P78pQGvwMBZAe+LPTtSZ
A0ANmaRMPp0VQJKpkFBTughA5zpfJFwQFUBIvuLkXoINQCoV39R6kxRAv1UY
7vxYEUBFscDkZREUQCnzB7OQxBNAf01r9mabE0DTfHUp7GMWQD1zeJk3HhNA
HW89YQ73GEDn7wPHzKUSQDcITuL2XRtAosDrDGY4EkCQjdwUp/gdQHYcvelb
xxFA3dxZyI4zIEAsuLDa2mcRQEGn8matZCFAjxFNsl4cEUDFZ0rer68iQCr+
aCSn7xBAsXtGepXkI0BenjIwg/0QQL2FAe9eMyVAc2UpY6paEUAZxGnEC3wm
QDK5ty+mCBJA3VV2vpuuJ0CeMA9krPASQMHdQZEP+yhAffyQDHAuFEAMubGI
ZjEqQEZaC9rTiRVAp8jO4KBhK0DppISC6wgXQGLOqhG/qyxA2HPxlzPIGECF
JytnwN8tQKsNR7T0ZBpAyHZqlaUtL0AqhN6lJwEcQLkMJ/S2MjBA+ydzu0xe
HUA2eO/NjMswQF9ADSkynx5Aw14XlFRxMUAYSKdYy+8fQM9JKZewfDFAMaAd
nEIDIEB/giPV
          "]]}}, {}}, {GraphicsComplexBox[CompressedData["
1:eJzt1us/1Hkfx/HBOjTCnM38fuMYMc5soyL9PqgQG1GZSTZKYlNTVnRCpaRU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        "], {
         {Hue[0.67, 0.6, 0.6], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 157], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 158], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 159], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 160], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 161], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 162], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 163], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 164], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 165], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 166], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 167], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 168], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 169], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 170], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 171], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 172], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 173], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 174], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 175], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 176], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 177], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 178], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 179], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 180], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 181], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 182], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 183], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 184], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 185], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 186], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 187], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 188], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 189], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 190], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 191], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 192], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 193], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 194], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 195], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 196], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 197], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 198], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 199], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 200], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 201], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 202], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 203], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 204], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 205], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 206], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 207], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 208], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 209], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 210], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 211], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 212], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 213], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 214], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 215], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 216], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 217], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 218], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 219], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 220], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 221], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 222], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 223], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 224], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 225], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 226], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 227], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 228], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 229], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 230], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 231], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 232], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 233], InsetBox[
           StyleBox["\<\"\[FilledLeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 234]}, 
         {Hue[0.9060679774997897, 0.6, 0.6], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 235], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 236], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 237], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 238], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 239], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 240], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 241], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 242], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 243], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 244], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 245], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 246], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 247], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 248], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 249], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 250], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 251], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 252], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 253], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 254], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 255], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 256], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 257], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 258], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 259], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 260], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 261], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 262], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 263], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 264], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 265], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 266], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 267], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 268], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 269], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 270], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 271], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 272], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 273], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 274], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 275], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 276], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 277], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 278], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 279], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 280], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 281], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 282], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 283], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 284], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 285], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 286], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 287], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 288], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 289], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 290], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 291], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 292], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 293], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 294], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 295], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 296], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 297], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 298], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 299], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 300], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 301], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 302], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 303], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 304], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 305], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 306], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 307], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 308], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 309], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 310], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 311], InsetBox[
           StyleBox["\<\"\[LeftTriangle]\"\>",
            StripOnInput->False,
            LineColor->RGBColor[0, 0, 1],
            FrontFaceColor->RGBColor[0, 0, 1],
            BackFaceColor->RGBColor[0, 0, 1],
            GraphicsColor->RGBColor[0, 0, 1],
            FontSize->Medium,
            FontColor->RGBColor[0, 0, 1]], 312]}, {}}], {}}},
     AspectRatio->0.7,
     AxesOrigin->{-5.298317366548036, -1.2039728043259361`},
     BaseStyle->{FontSize -> 15, FontFamily -> "Arial"},
     CoordinatesToolOptions:>{"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )},
     Frame->True,
     FrameLabel->{{
        FormBox[
        "\"\\!\\(\\*SuperscriptBox[\\(G\\), \\(*\\)]\\), kPa\"", 
         TraditionalForm], None}, {
        FormBox["\"\[Omega], rad/s\"", TraditionalForm], None}},
     FrameTicks->{{{{-2.3025850929940455`, 
          FormBox["0.1`", TraditionalForm]}, {0., 
          FormBox["1", TraditionalForm]}, {2.302585092994046, 
          FormBox["10", TraditionalForm]}, {4.605170185988092, 
          FormBox["100", TraditionalForm]}, {6.907755278982137, 
          FormBox["1000", TraditionalForm]}, {-1.6094379124341003`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.203972804325936, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.916290731874155, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.6931471805599453, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.5108256237659905, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.35667494393873245`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.2231435513142097, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.10536051565782616`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {0.6931471805599453, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.0986122886681098`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.3862943611198906`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.6094379124341003`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.791759469228055, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.9459101490553132`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.0794415416798357`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.1972245773362196`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.995732273553991, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.4011973816621555`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.912023005428146, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.0943445622221, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.248495242049359, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.382026634673881, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.499809670330265, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.298317366548036, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.703782474656201, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.991464547107982, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.214608098422191, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.396929655216146, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.551080335043404, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.684611727667927, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.802394763324311, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, {{-2.3025850929940455`, 
          FormBox["\"\"", TraditionalForm]}, {0., 
          FormBox["\"\"", TraditionalForm]}, {2.302585092994046, 
          FormBox["\"\"", TraditionalForm]}, {4.605170185988092, 
          FormBox["\"\"", TraditionalForm]}, {6.907755278982137, 
          FormBox["\"\"", TraditionalForm]}, {-1.6094379124341003`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.203972804325936, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.916290731874155, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.6931471805599453, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.5108256237659905, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.35667494393873245`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.2231435513142097, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.10536051565782616`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {0.6931471805599453, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.0986122886681098`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.3862943611198906`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.6094379124341003`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.791759469228055, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.9459101490553132`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.0794415416798357`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.1972245773362196`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.995732273553991, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.4011973816621555`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.912023005428146, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.0943445622221, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.248495242049359, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.382026634673881, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.499809670330265, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.298317366548036, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.703782474656201, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.991464547107982, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.214608098422191, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.396929655216146, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.551080335043404, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.684611727667927, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.802394763324311, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}}, {{{-4.605170185988091, 
          FormBox["0.01`", TraditionalForm]}, {0., 
          FormBox["1", TraditionalForm]}, {4.605170185988092, 
          FormBox["100", TraditionalForm]}, {9.210340371976184, 
          FormBox[
           
           TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm]}, {13.815510557964274`, 
          FormBox[
           
           TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm]}, {-2.120263536200091, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.4696759700589417`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.07880966137193, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.7985076962177716, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.579818495252942, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.40047756659712525`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.2484613592984996, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.11653381625595151`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.4849066497880004`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.1354942159291497`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.5263605246161616`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.8066624897703196`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.02535169073515, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.204692619390966, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.356708826689592, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.48863636973214, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {7.090076835776092, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {7.7406644019172415`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.131530710604252, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.411832675758411, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.630521876723241, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.809862805379057, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.961879012677683, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {9.093806555720231, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {11.695247021764184`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {12.345834587905333`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {12.736700896592344`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {13.017002861746503`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {13.235692062711331`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {13.415032991367148`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {13.567049198665774`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {13.698976741708323`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, {{-4.605170185988091, 
          FormBox["\"\"", TraditionalForm]}, {0., 
          FormBox["\"\"", TraditionalForm]}, {4.605170185988092, 
          FormBox["\"\"", TraditionalForm]}, {9.210340371976184, 
          FormBox["\"\"", TraditionalForm]}, {13.815510557964274`, 
          FormBox["\"\"", TraditionalForm]}, {-2.120263536200091, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.4696759700589417`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.07880966137193, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.7985076962177716, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.579818495252942, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.40047756659712525`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.2484613592984996, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.11653381625595151`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.4849066497880004`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.1354942159291497`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.5263605246161616`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.8066624897703196`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.02535169073515, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.204692619390966, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.356708826689592, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.48863636973214, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {7.090076835776092, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {7.7406644019172415`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.131530710604252, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.411832675758411, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.630521876723241, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.809862805379057, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.961879012677683, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {9.093806555720231, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {11.695247021764184`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {12.345834587905333`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {12.736700896592344`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {13.017002861746503`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {13.235692062711331`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {13.415032991367148`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {13.567049198665774`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {13.698976741708323`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}}},
     GridLines->{None, None},
     ImageSize->520,
     Method->{},
     PlotRange->{{-5.298317366548036, 
      16.811242831518264`}, {-1.2039728043259361`, 8.006367567650246}},
     PlotRangeClipping->True,
     PlotRangePadding->{{None, None}, {None, None}},
     Ticks->{{{-4.605170185988091, 
         FormBox["0.01`", TraditionalForm]}, {0., 
         FormBox["1", TraditionalForm]}, {4.605170185988092, 
         FormBox["100", TraditionalForm]}, {9.210340371976184, 
         FormBox[
          
          TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
           SuperscriptBox], TraditionalForm]}, {13.815510557964274`, 
         FormBox[
          
          TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> 
           SuperscriptBox], TraditionalForm]}, {-2.120263536200091, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.4696759700589417`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.07880966137193, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.7985076962177716, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.579818495252942, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.40047756659712525`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.2484613592984996, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.11653381625595151`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.4849066497880004`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.1354942159291497`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.5263605246161616`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.8066624897703196`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.02535169073515, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.204692619390966, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.356708826689592, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.48863636973214, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {7.090076835776092, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {7.7406644019172415`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.131530710604252, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.411832675758411, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.630521876723241, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.809862805379057, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.961879012677683, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {9.093806555720231, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.695247021764184`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {12.345834587905333`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {12.736700896592344`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {13.017002861746503`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {13.235692062711331`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {13.415032991367148`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {13.567049198665774`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {13.698976741708323`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}, {{-2.3025850929940455`, 
         FormBox["0.1`", TraditionalForm]}, {0., 
         FormBox["1", TraditionalForm]}, {2.302585092994046, 
         FormBox["10", TraditionalForm]}, {4.605170185988092, 
         FormBox["100", TraditionalForm]}, {6.907755278982137, 
         FormBox["1000", TraditionalForm]}, {-1.6094379124341003`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.203972804325936, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.916290731874155, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.6931471805599453, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.5108256237659905, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.35667494393873245`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.2231435513142097, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.10536051565782616`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.6931471805599453, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.0986122886681098`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.3862943611198906`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.6094379124341003`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.791759469228055, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.9459101490553132`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.0794415416798357`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.1972245773362196`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.995732273553991, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.4011973816621555`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.6888794541139363`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.912023005428146, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.0943445622221, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.248495242049359, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.382026634673881, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.499809670330265, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.298317366548036, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.703782474656201, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.991464547107982, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.214608098422191, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.396929655216146, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.551080335043404, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.684611727667927, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.802394763324311, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}}], {-1, -0.7}, {Left, Bottom}, {2, 1.4}], 
   GraphicsGroupBox[{
     {GrayLevel[0], RectangleBox[{-0.28, -0.4}, {0.72, -0.2}]}, 
     {GrayLevel[1], EdgeForm[{GrayLevel[0], Thickness[0.001]}], 
      GraphicsGroupBox[{RectangleBox[{-0.28, -0.4}, {0.72, -0.2}], InsetBox[
         GraphicsBox[{{{InsetBox[
              GraphicsBox[
               {RGBColor[1, 0, 0], Thickness[Large], 
                LineBox[{{0, 0}, {2, 0}}]}], {0.08, 0.08}, {
              Left, Bottom}, {1, 1}], InsetBox[
              InterpretationBox[Cell[BoxData[
                FormBox[
                 StyleBox["\<\"Eq.(14) with Procedure VA\"\>",
                  StripOnInput->False,
                  FontFamily->"Arial",
                  FontSize->13], TextForm]], "InlineText"],
               Text[
                Style[
                "Eq.(14) with Procedure VA", FontSize -> 13, FontFamily -> 
                 "Arial"]]], {1.2100000000000002`, 0.58}, {-1, 0}, 
              Automatic, {1, 0}]}, {InsetBox[
              StyleBox["\<\"\[FilledUpTriangle]\"\>",
               StripOnInput->False,
               LineColor->RGBColor[0, 0, 1],
               FrontFaceColor->RGBColor[0, 0, 1],
               BackFaceColor->RGBColor[0, 0, 1],
               GraphicsColor->RGBColor[0, 0, 1],
               FontSize->Medium,
               FontColor->RGBColor[0, 0, 1]], {0.08, 1.24}, {
              Left, Bottom}, {1, 1}], InsetBox[
              InterpretationBox[Cell[BoxData[
                FormBox[
                 StyleBox["\<\"Experiment\"\>",
                  StripOnInput->False,
                  FontFamily->"Arial",
                  FontSize->13], TextForm]], "InlineText"],
               Text[
                Style[
                "Experiment", FontSize -> 13, FontFamily -> 
                 "Arial"]]], {1.2100000000000002`, 1.74}, {-1, 0}, 
              Automatic, {1, 0}]}}, {}},
          AspectRatio->0.2,
          PlotRange->{{-0.1, 5.26}, {-0.1, 2.42}}], {-0.28, -0.4}, {
         Left, Bottom}, {1, 0.2}]}]}}]},
  AspectRatio->Automatic,
  Background->None,
  ColorOutput->Automatic,
  ImageSize->520.,
  PlotRange->All]], "Output",
 CellChangeTimes->{
  3.6230856971431203`*^9, 3.6230860250318747`*^9, {3.6230860605569067`*^9, 
   3.623086077378868*^9}, {3.623086183827957*^9, 3.6230862188199587`*^9}, 
   3.6230865909922457`*^9, 3.6230896689302936`*^9, 3.6230897153339477`*^9, {
   3.623089788375125*^9, 3.623089825510249*^9}, 3.623159026301308*^9, 
   3.6231596803857193`*^9, {3.623163645934536*^9, 3.623163658273242*^9}, {
   3.6231641909687104`*^9, 3.62316425687648*^9}, 3.623164326028435*^9, 
   3.6231663153182163`*^9, {3.6231665308025413`*^9, 3.6231665577080803`*^9}, 
   3.623166697873097*^9, {3.623170957521735*^9, 3.623170985003307*^9}, 
   3.6233280830010014`*^9, 3.627238688733454*^9, 3.6272387597615995`*^9, 
   3.6272388749548273`*^9, 3.6297396900312076`*^9, 3.629742452851473*^9, 
   3.63089712662039*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell["\<\
The resulting parameters for the DSM are listed below:\
\>", "Text",
 CellChangeTimes->{{3.6231637390228605`*^9, 3.623163782655356*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Style", "[", 
  RowBox[{
   RowBox[{"TableForm", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Last", "[", "FullGs", "]"}], "}"}], ",", 
     RowBox[{"TableHeadings", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", "\"\<PB\>\"", "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<\!\(\*SubscriptBox[\(\[Omega]\), \(x\)]\)[rad/s]\>\"", ",", 
          "\"\<\!\(\*SubscriptBox[
StyleBox[\"G\",
FontSlant->\"Italic\"], \"x\"]\)[kPa]\>\"", ",", "\"\<\!\(\*SubscriptBox[
StyleBox[\"M\",
FontSlant->\"Italic\"], \"c\"]\)[Da]\>\"", ",", "\"\<\!\(\*SubscriptBox[
StyleBox[\"N\",
FontSlant->\"Italic\"], \"c\"]\)\>\"", ",", 
          "\"\<\!\(\*SubscriptBox[\(\[Tau]\), \(c\)]\)[s]\>\"", ",", 
          "\"\<\[Beta]\>\"", ",", 
          "\"\<\!\(\*SubscriptBox[\(\[Tau]\), \(K\)]\)[s]\>\"", ",", 
          "\"\<\!\(\*SubscriptBox[
StyleBox[\"N\",
FontSlant->\"Italic\"], \"K\"]\)\>\""}], "}"}]}], "}"}]}], ",", 
     RowBox[{"TableAlignments", "\[Rule]", "Center"}]}], "]"}], ",", 
   RowBox[{"FontSize", "\[Rule]", "18"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5891367506227765`*^9, 3.5891368026387515`*^9}, {
   3.589136868403513*^9, 3.589136907610756*^9}, {3.589139480245902*^9, 
   3.589139500511061*^9}, {3.5891497686210003`*^9, 3.589149822614088*^9}, {
   3.5891498829905415`*^9, 3.5891498906409793`*^9}, {3.5891504794276557`*^9, 
   3.589150492292392*^9}, {3.589153013980624*^9, 3.589153033774756*^9}, {
   3.6095155353325777`*^9, 3.6095156133550406`*^9}, {3.6095156502921534`*^9, 
   3.6095157865109444`*^9}, {3.6095158256541834`*^9, 
   3.6095159328463144`*^9}, {3.60951600025517*^9, 3.609516030349891*^9}, {
   3.6095166608769555`*^9, 3.609516661158972*^9}, {3.609517440790564*^9, 
   3.6095175239393196`*^9}, {3.6095175619984965`*^9, 
   3.6095176228209753`*^9}, {3.609612498057208*^9, 3.609612524531722*^9}, {
   3.6097747020133576`*^9, 3.6097747032844305`*^9}, {3.609774734972243*^9, 
   3.6097747390114737`*^9}, {3.61171291544407*^9, 3.611712984810037*^9}, {
   3.616250524143653*^9, 3.6162505460536833`*^9}, {3.6164328585403423`*^9, 
   3.6164328661897798`*^9}, 3.6230838037368236`*^9, {3.623084789612212*^9, 
   3.623084797180645*^9}, {3.6230861197972946`*^9, 3.6230861693821306`*^9}, {
   3.623163798993291*^9, 3.6231638286609874`*^9}, 3.623164342126356*^9, {
   3.623328554393849*^9, 3.623328573398193*^9}}],

Cell[BoxData[
 StyleBox[
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"\\!\\(\\*SubscriptBox[\\(\[Omega]\\), \\(x\\)]\\)[rad/s]\"\
\>",
        HoldForm], 
       TagBox["\<\"\\!\\(\\*SubscriptBox[\\n \
StyleBox[\\\"G\\\",\\nFontSlant->\\\"Italic\\\"], \\\"x\\\"]\\)[kPa]\"\>",
        HoldForm], 
       TagBox["\<\"\\!\\(\\*SubscriptBox[\\n \
StyleBox[\\\"M\\\",\\nFontSlant->\\\"Italic\\\"], \\\"c\\\"]\\)[Da]\"\>",
        HoldForm], 
       TagBox["\<\"\\!\\(\\*SubscriptBox[\\n \
StyleBox[\\\"N\\\",\\nFontSlant->\\\"Italic\\\"], \\\"c\\\"]\\)\"\>",
        HoldForm], 
       TagBox["\<\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(c\\)]\\)[s]\"\>",
        HoldForm], 
       TagBox["\<\"\[Beta]\"\>",
        HoldForm], 
       TagBox["\<\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(K\\)]\\)[s]\"\>",
        HoldForm], 
       TagBox["\<\"\\!\\(\\*SubscriptBox[\\n \
StyleBox[\\\"N\\\",\\nFontSlant->\\\"Italic\\\"], \\\"K\\\"]\\)\"\>",
        HoldForm]},
      {
       TagBox["\<\"PB\"\>",
        HoldForm], "1.6308375000000002`", "297.48375000000004`", 
       "806.8222499353836`", "252.8437955402666`", "3.6058583481298614`*^-7", 
       "12.866737418111224`", "1.4968569101152619`*^-9", "1963.4263715110683`"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"PB"}, {
       "\!\(\*SubscriptBox[\(\[Omega]\), \(x\)]\)[rad/s]", 
        "\!\(\*SubscriptBox[\n StyleBox[\"G\",\nFontSlant->\"Italic\"], \
\"x\"]\)[kPa]", 
        "\!\(\*SubscriptBox[\n StyleBox[\"M\",\nFontSlant->\"Italic\"], \
\"c\"]\)[Da]", 
        "\!\(\*SubscriptBox[\n StyleBox[\"N\",\nFontSlant->\"Italic\"], \
\"c\"]\)", "\!\(\*SubscriptBox[\(\[Tau]\), \(c\)]\)[s]", "\[Beta]", 
        "\!\(\*SubscriptBox[\(\[Tau]\), \(K\)]\)[s]", 
        "\!\(\*SubscriptBox[\n StyleBox[\"N\",\nFontSlant->\"Italic\"], \
\"K\"]\)"}}, TableAlignments -> Center]]],
  StripOnInput->False,
  FontSize->18]], "Output",
 CellChangeTimes->{{3.6231638095718956`*^9, 3.6231638296830463`*^9}, {
   3.6231643274805183`*^9, 3.6231643430604095`*^9}, 3.623164397910547*^9, 
   3.6231663167422976`*^9, {3.623170957710746*^9, 3.623170985263322*^9}, 
   3.6233280836270103`*^9, 3.6233285751562214`*^9, 3.6272386890484557`*^9, 
   3.6272387599336004`*^9, 3.6272388751248274`*^9, 3.629739690337225*^9, 
   3.6297424530454736`*^9, 3.63089712732843*^9},
 Background->RGBColor[0.88, 1, 0.88]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["References", "Section",
 CellChangeTimes->{{3.6231718212301364`*^9, 3.623171823477265*^9}}],

Cell[TextData[{
 " ",
 "1",
 ". ",
 "Andreev, Marat and Feng, Hualong and Yang, Ling and Schieber, Jay D",
 ", ",
 StyleBox["Universality and speedup in equilibrium and nonlinear rheology \
predictions of the fixed slip-link model",
  FontSlant->"Italic"],
 ". ",
 "Journal of Rheology ",
 ", ",
 "2014",
 "."
}], "Reference",
 Editable->False,
 TaggingRules->{ReferenceData -> ""},
 CellTags->"bibl:andreev2014universality"],

Cell[TextData[{
 " ",
 "2",
 ". ",
 "Khaliullin, Renat N and Schieber, Jay D",
 ", ",
 StyleBox["Application of the slip-link model to bidisperse systems",
  FontSlant->"Italic"],
 ". ",
 "Macromolecules",
 ", ",
 "2010",
 "."
}], "Reference",
 Editable->False,
 TaggingRules->{ReferenceData -> ""},
 CellTags->"bibl:khaliullin2010application"],

Cell[TextData[{
 " ",
 "3",
 ". ",
 "Pilyugina, Ekaterina and Andreev, Marat and Schieber, Jay D",
 ", ",
 StyleBox["Dielectric relaxation as an independent examination of relaxation \
mechanisms in entangled polymers using the discrete slip-link model",
  FontSlant->"Italic"],
 ". ",
 "Macromolecules",
 ", ",
 "2012",
 "."
}], "Reference",
 Editable->False,
 TaggingRules->{ReferenceData -> ""},
 CellTags->"bibl:pilyugina2012dielectric"],

Cell[TextData[{
 " ",
 "4",
 ". ",
 "Jensen, Mette Krog and Khaliullin, Renat and Schieber, Jay D",
 ", ",
 StyleBox["Self-consistent modeling of entangled network strands and linear \
dangling structures in a single-strand mean-field slip-link model",
  FontSlant->"Italic"],
 ". ",
 "Rheologica acta",
 ", ",
 "2012",
 "."
}], "Reference",
 Editable->False,
 TaggingRules->{ReferenceData -> ""},
 CellTags->"bibl:jensen2012self"],

Cell[TextData[{
 " ",
 "5",
 ". ",
 "Katzarova, Maria and Andreev, Marat and Sliozberg, Yelena R and Mrozek, \
Randy A and Lenhart, Joseph L and Andzelm, Jan W and Schieber, Jay D",
 ", ",
 StyleBox["Rheological predictions of network systems swollen with entangled \
solvent",
  FontSlant->"Italic"],
 ". ",
 "AIChE Journal",
 ", ",
 "2014",
 "."
}], "Reference",
 Editable->False,
 TaggingRules->{ReferenceData -> ""},
 CellTags->"bibl:katzarova2014rheological"],

Cell[TextData[{
 " ",
 "6",
 ". ",
 "Baumgaertel, M and Schausberger, A and Winter, HH",
 ", ",
 StyleBox["The relaxation of polymers with linear flexible chains of uniform \
length",
  FontSlant->"Italic"],
 ". ",
 "Rheologica Acta",
 ", ",
 "1990",
 "."
}], "Reference",
 Editable->False,
 TaggingRules->{ReferenceData -> ""},
 CellTags->"bibl:baumgaertel1990relaxation"],

Cell[TextData[{
 " ",
 "7",
 ". ",
 "van Ruymbeke, Evelyne and Coppola, Salvatore and Balacca, Letizia and \
Righi, Sandra and Vlassopoulos, Dimitris",
 ", ",
 StyleBox["Decoding the viscoelastic response of polydisperse star/linear \
polymer blends",
  FontSlant->"Italic"],
 ". ",
 "Journal of Rheology (1978-present)",
 ", ",
 "2010",
 "."
}], "Reference",
 Editable->False,
 TaggingRules->{ReferenceData -> ""},
 CellTags->"bibl:van2010decoding"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1664, 915},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"JournalStyle"->"Indexed",
"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
FrontEndVersion->"9.0 for Microsoft Windows (64-bit) (January 25, 2013)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]]}, Visible -> False, 
  FrontEndVersion -> "9.0 for Microsoft Windows (64-bit) (January 25, 2013)", 
  StyleDefinitions -> "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "bibl:andreev2014universality"->{
  Cell[276307, 5909, 425, 17, 21, "Reference",
   CellTags->"bibl:andreev2014universality"]},
 "bibl:khaliullin2010application"->{
  Cell[276735, 5928, 344, 16, 21, "Reference",
   CellTags->"bibl:khaliullin2010application"]},
 "bibl:pilyugina2012dielectric"->{
  Cell[277082, 5946, 441, 17, 21, "Reference",
   CellTags->"bibl:pilyugina2012dielectric"]},
 "bibl:jensen2012self"->{
  Cell[277526, 5965, 431, 17, 21, "Reference",
   CellTags->"bibl:jensen2012self"]},
 "bibl:katzarova2014rheological"->{
  Cell[277960, 5984, 464, 18, 21, "Reference",
   CellTags->"bibl:katzarova2014rheological"]},
 "bibl:baumgaertel1990relaxation"->{
  Cell[278427, 6004, 373, 17, 21, "Reference",
   CellTags->"bibl:baumgaertel1990relaxation"]},
 "bibl:van2010decoding"->{
  Cell[278803, 6023, 450, 18, 21, "Reference",
   CellTags->"bibl:van2010decoding"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"bibl:andreev2014universality", 279911, 6061},
 {"bibl:khaliullin2010application", 280042, 6064},
 {"bibl:pilyugina2012dielectric", 280173, 6067},
 {"bibl:jensen2012self", 280293, 6070},
 {"bibl:katzarova2014rheological", 280414, 6073},
 {"bibl:baumgaertel1990relaxation", 280546, 6076},
 {"bibl:van2010decoding", 280669, 6079}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 260, 5, 166, "Title"],
Cell[830, 29, 1695, 46, 206, "Text"],
Cell[2528, 77, 2461, 47, 75, "Text"],
Cell[4992, 126, 6224, 85, 31, "Input"],
Cell[CellGroupData[{
Cell[11241, 215, 135, 2, 86, "Section"],
Cell[11379, 219, 972, 23, 40, "Text"],
Cell[12354, 244, 7868, 202, 331, "Input"],
Cell[20225, 448, 420, 7, 30, "Text"],
Cell[20648, 457, 5800, 143, 313, "Input"],
Cell[26451, 602, 292, 7, 30, "Text"],
Cell[26746, 611, 2058, 59, 108, "Input"],
Cell[28807, 672, 3357, 81, 89, "Text"],
Cell[32167, 755, 30001, 491, 377, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[62205, 1251, 386, 6, 86, "Section"],
Cell[CellGroupData[{
Cell[62616, 1261, 604, 20, 49, "Subsection"],
Cell[63223, 1283, 863, 26, 35, "Text"],
Cell[64089, 1311, 740, 21, 108, "Input"],
Cell[CellGroupData[{
Cell[64854, 1336, 338, 5, 34, "Subsubsection"],
Cell[65195, 1343, 2833, 71, 59, "Text"],
Cell[CellGroupData[{
Cell[68053, 1418, 11002, 256, 436, "Input"],
Cell[79058, 1676, 76808, 1750, 381, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[155915, 3432, 183, 3, 34, "Subsubsection"],
Cell[156101, 3437, 1330, 25, 33, "Input"],
Cell[CellGroupData[{
Cell[157456, 3466, 8010, 171, 179, "Input"],
Cell[165469, 3639, 405, 9, 21, "Message"],
Cell[165877, 3650, 104562, 2120, 382, 87063, 1833, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]],
Cell[270454, 5773, 146, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[270625, 5780, 2391, 46, 52, "Input"],
Cell[273019, 5828, 3115, 70, 70, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[276207, 5906, 97, 1, 86, "Section"],
Cell[276307, 5909, 425, 17, 21, "Reference",
 CellTags->"bibl:andreev2014universality"],
Cell[276735, 5928, 344, 16, 21, "Reference",
 CellTags->"bibl:khaliullin2010application"],
Cell[277082, 5946, 441, 17, 21, "Reference",
 CellTags->"bibl:pilyugina2012dielectric"],
Cell[277526, 5965, 431, 17, 21, "Reference",
 CellTags->"bibl:jensen2012self"],
Cell[277960, 5984, 464, 18, 21, "Reference",
 CellTags->"bibl:katzarova2014rheological"],
Cell[278427, 6004, 373, 17, 21, "Reference",
 CellTags->"bibl:baumgaertel1990relaxation"],
Cell[278803, 6023, 450, 18, 21, "Reference",
 CellTags->"bibl:van2010decoding"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
